{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "This workflow represents the GATK Best Practices for SNP and INDEL calling on DNA data.\n\nStarting from a processed **BAM** file, the workflow performs variant calling with respect to the reference genome. Depending on **HaplotypeCaller's** output file type (**VCF** or **g.VCF**, the resulting file of this workflow can be used as a stand alone result for single-sample analysis, or as one of the cohort files downstream joint calling analysis. On the GATK website you can find more detailed information about calling germline variants for single sample or joint calling analysis [1].\n\n### Common Use Cases\n\n* The **haplotypecaller-gvcf-gatk4** (original WDL name) workflow [1] runs the **HaplotypeCaller** tool from GATK4 in GVCF mode on a single sample according to GATK Best Practices. \n* To run HaplotypeCaller in a mode appropriate for joint calling analysis, one needs to set (`--emit_ref_confidence`) parameter to GVCF. \n* When executed, the workflow scatters the **HaplotypeCaller** tool over the **Calling intervals** file (`--in_intervals`). \n* The resulting g.VCF files are merged with **GATK MergeVCF**. \n* The output file produced will be a single g.VCF file which can be further processed in joint-discovery workflow. \n* By default, the output file is compressed with gzip, leading to a G.VCF.GZ extension.\n\n* This workflow can also be used for single sample analysis. For that purpose, it produces a VCF file which is obtained by setting (the `--emit_ref_confidence`) parameter to NONE. \n\n\n### Changes Introduced by Seven Bridges\n\n* The original **Generic germline variant per-sample calling** WDL implementation has a step called **CramToBamTask** which accepts CRAM files and converts them to BAM files with **samtools view**, while also indexing them. In this CWL implementation, this step is skipped as **GATK HaplotypeCaller** has the option to work with CRAM files. Keep in mind that CRAM files need to be indexed. \n\n* To enable scattering of **GATK Haplotypecallier** tool, we have introduced the **GATK IntervalListTool**, solution given in **GATK Production Germline short variant per-sample calling** [2]. \n\n### Common Issues and Important Notes\n\n* The **HaplotypeCaller** app uses **Intervals list** to restrict processing to specific genomic intervals. You can set the **Scatter count** value in order to split **Intervals list** into smaller intervals. **HaplotypeCaller** processes these intervals in parallel, which can significantly reduce workflow execution time in some cases.\n\n* The workflow accepts multiple flowcell BAMs on input, however, they must all share the same sample ID. Otherwise, some GATK tools will fail.\n\n* Running a **batch task**: Batching is performed by **Sample ID** metadata field on the **Aligned and Processed BAM** input port. For running analyses in batches, it is necessary to set **Sample ID** metadata for each **Processed and aligned BAM** file.\n\n### Performance Benchmarking\n                   \n|  BAM Input size | Experiment type | Coverage | Duration | Cost | Instance |\n|-----------------------|-----------------       |------------   |-------------|--------|--------------|\n| 55.8GiB              |  WGS           (scatter count = 20)     | ~50x            |  17h 35min   | $9.42           | c4.2xlarge |\n| 55.8GiB              |  WGS           (scatter count = 80)     | ~50x            |  10h 32min   | $5.64           | c4.2xlarge |\n| 24.6GiB              |  WGS           (scatter count = 80)     | ~10x            |  4h 12min     | $2.25           | c4.2xlarge |\n| 3.5GiB                |  WES            (scatter count = 1)    | ~70x             |  17min          | $0.16           | c4.2xlarge |\n| 1.9GiB                |  WES            (scatter count = 1)    | ~40x             |  11min          | $0.11           | c4.2xlarge | \n| 1.1GiB                |  WES            (scatter count = 1)    | ~20x             |  9min            | $0.08           | c4.2xlarge | \n| 434MiB               |  WES            (scatter count = 1)    | ~10x             |  6min            | $0.06           | c4.2xlarge | \n\n\n\n### API Python Implementation\nThe app's draft task can also be submitted via the **API**. In order to learn how to get your **Authentication token** and **API endpoint** for corresponding platform visit our [documentation](https://github.com/sbg/sevenbridges-python#authentication-and-configuration).\n\n```python\n# Initialize the SBG Python API\nfrom sevenbridges import Api\napi = Api(token=\"enter_your_token\", url=\"enter_api_endpoint\")\nproject_id = \"your_username/project\"\napp_id = \"your_username/project/app\"\n# Replace inputs with appropriate values\ninputs = {\n        \"in_reference\": api.files.query(project=project_id, names=[\"Homo_sapiens_assembly38.fasta\"])[0], \n\t\"in_alignments\": list(api.files.query(project=project_id, names=[\"HCC1143BL_WES_1.processed.bam\"])), \n\t\"in_intervals\": list(api.files.query(project=project_id, names=[\"wgs_calling_regions.hg38.interval_list\"]))}\n\n# Creates draft task\ntask = api.tasks.create(name=\"GATK Best Practice Germline snps and indels 4.1.0.0 - API Run\", project=project_id, app=app_id, inputs=inputs, run=False)\n```\n\nInstructions for installing and configuring the API Python client, are provided on [github](https://github.com/sbg/sevenbridges-python#installation). For more information about using the API Python client, consult [the client documentation](http://sevenbridges-python.readthedocs.io/en/latest/). **More examples** are available [here](https://github.com/sbg/okAPI).\n\nAdditionally, [API R](https://github.com/sbg/sevenbridges-r) and [API Java](https://github.com/sbg/sevenbridges-java) clients are available. To learn more about using these API clients please refer to the [API R client documentation](https://sbg.github.io/sevenbridges-r/), and [API Java client documentation](https://docs.sevenbridges.com/docs/java-library-quickstart).\n\n### References\n\n[1] [Broad germline SNPS and INDELS](https://github.com/gatk-workflows/gatk4-germline-snps-indels)\n\n[2] [Broad Producion WGS germline SNPs and INDELs](https://github.com/gatk-workflows/broad-prod-wgs-germline-snps-indels)",
            "id": "#main",
            "inputs": [
                {
                    "doc": "Reference FASTA file.",
                    "id": "#main/in_reference",
                    "label": "Reference",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "type": "File",
                    "https://sevenbridges.comfileTypes": "FASTA, FA",
                    "https://sevenbridges.comx": -566.26904296875,
                    "https://sevenbridges.comy": -155.61929321289062
                },
                {
                    "doc": "Aligned and processed BAM that has to match reference file provided on the *Reference* input.",
                    "id": "#main/in_alignments",
                    "label": "Aligned and Processed BAM",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "https://sevenbridges.comfileTypes": "BAM, SAM, CRAM",
                    "https://sevenbridges.comx": -553.3858032226562,
                    "https://sevenbridges.comy": 29.294416427612305
                },
                {
                    "doc": "Fraction of contamination to aggressively remove.",
                    "id": "#main/contamination_fraction_to_filter",
                    "label": "Fraction of contamination",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "Mode for emitting reference confidence scores.",
                    "id": "#main/emit_ref_confidence",
                    "label": "Emitting reference confidence scores",
                    "type": [
                        "null",
                        {
                            "name": "#main/emit_ref_confidence/emit_ref_confidence",
                            "symbols": [
                                "#main/emit_ref_confidence/emit_ref_confidence/NONE",
                                "#main/emit_ref_confidence/emit_ref_confidence/BP_RESOLUTION",
                                "#main/emit_ref_confidence/emit_ref_confidence/GVCF"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "File format of the resulting VCF file.",
                    "id": "#main/output_file_format",
                    "label": "File format",
                    "type": [
                        "null",
                        {
                            "name": "#main/output_file_format/output_file_format",
                            "symbols": [
                                "#main/output_file_format/output_file_format/vcf",
                                "#main/output_file_format/output_file_format/bcf",
                                "#main/output_file_format/output_file_format/vcf.gz"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "Which type of calls we should output.",
                    "id": "#main/output_mode",
                    "label": "Output mode",
                    "type": [
                        "null",
                        {
                            "name": "#main/output_mode/output_mode",
                            "symbols": [
                                "#main/output_mode/output_mode/EMIT_VARIANTS_ONLY",
                                "#main/output_mode/output_mode/EMIT_ALL_CONFIDENT_SITES",
                                "#main/output_mode/output_mode/EMIT_ALL_SITES"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "Extension of the HaplotypeCaller's resulting VCF file - gzipped or not.",
                    "id": "#main/output_extension",
                    "label": "HaplotypeCaller's resulting VCF file extension",
                    "type": [
                        "null",
                        {
                            "name": "#main/output_extension/output_extension",
                            "symbols": [
                                "#main/output_extension/output_extension/vcf",
                                "#main/output_extension/output_extension/vcf.gz"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "File with intervals that should be considered for variant calling. This file can be obtained from BED file using GATK BedToIntervalList.",
                    "id": "#main/in_intervals",
                    "label": "Calling intervals",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "https://sevenbridges.comfileTypes": "VCF, INTERVAL_LIST",
                    "https://sevenbridges.comx": -743,
                    "https://sevenbridges.comy": -345
                },
                {
                    "doc": "Interval list naming - unique or not",
                    "id": "#main/unique",
                    "label": "Interval list naming options",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "Mode for scattering of the interval-list.",
                    "id": "#main/subdivision_mode",
                    "label": "Scattering mode",
                    "type": [
                        "null",
                        {
                            "name": "#main/subdivision_mode/subdivision_mode",
                            "symbols": [
                                "#main/subdivision_mode/subdivision_mode/INTERVAL_SUBDIVISION",
                                "#main/subdivision_mode/subdivision_mode/BALANCING_WITHOUT_INTERVAL_SUBDIVISION",
                                "#main/subdivision_mode/subdivision_mode/BALANCING_WITHOUT_INTERVAL_SUBDIVISION_WITH_OVERFLOW",
                                "#main/subdivision_mode/subdivision_mode/INTERVAL_COUNT"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "Sort the resulting interval list by coordinate.",
                    "id": "#main/sort",
                    "label": "Sort interval list by coordinate",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "The number of files into which to scatter the resulting list by locus.",
                    "id": "#main/scatter_count",
                    "label": "Scatter count",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "Create a new interval list with the original intervals broken up at integer multiples of this value.",
                    "id": "#main/break_bands_at_multiples_of",
                    "label": "Redefine scatter intervals",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "CPU per job.",
                    "id": "#main/cpu_per_job",
                    "label": "CPU per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comexposed": true
                },
                {
                    "doc": "Memory per job.",
                    "id": "#main/mem_per_job",
                    "label": "Memory per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comexposed": true
                }
            ],
            "label": "Broad Best Practice Germline snps and indels variant calling 4.1.0.0",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/contamination_fraction_to_filter",
                            "source": "#main/contamination_fraction_to_filter"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/emit_ref_confidence",
                            "source": "#main/emit_ref_confidence"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/in_alignments",
                            "source": [
                                "#main/in_alignments"
                            ]
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/include_intervals",
                            "source": "#main/gatk_intervallisttools_4_1_0_0/output_interval_list"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/mem_per_job",
                            "source": "#main/mem_per_job"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/output_mode",
                            "source": "#main/output_mode"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/in_reference",
                            "source": "#main/in_reference"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/cpu_per_job",
                            "source": "#main/cpu_per_job"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/output_extension",
                            "source": "#main/output_extension"
                        }
                    ],
                    "label": "GATK HaplotypeCaller",
                    "out": [
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/out_variants"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/out_alignments"
                        },
                        {
                            "id": "#main/gatk_haplotypecaller_4_1_0_0/out_graph"
                        }
                    ],
                    "run": "#gatk_haplotypecaller_4_1_0_0.cwl",
                    "scatter": [
                        "#main/gatk_haplotypecaller_4_1_0_0/include_intervals"
                    ],
                    "scatterMethod": "dotproduct",
                    "id": "#main/gatk_haplotypecaller_4_1_0_0",
                    "https://sevenbridges.comx": -349,
                    "https://sevenbridges.comy": -162
                },
                {
                    "in": [
                        {
                            "id": "#main/gatk_intervallisttools_4_1_0_0/break_bands_at_multiples_of",
                            "source": "#main/break_bands_at_multiples_of"
                        },
                        {
                            "id": "#main/gatk_intervallisttools_4_1_0_0/in_intervals",
                            "source": [
                                "#main/in_intervals"
                            ]
                        },
                        {
                            "id": "#main/gatk_intervallisttools_4_1_0_0/scatter_count",
                            "source": "#main/scatter_count"
                        },
                        {
                            "id": "#main/gatk_intervallisttools_4_1_0_0/sort",
                            "source": "#main/sort"
                        },
                        {
                            "id": "#main/gatk_intervallisttools_4_1_0_0/subdivision_mode",
                            "source": "#main/subdivision_mode"
                        },
                        {
                            "default": false,
                            "id": "#main/gatk_intervallisttools_4_1_0_0/unique",
                            "source": "#main/unique"
                        }
                    ],
                    "label": "GATK IntervalListTools",
                    "out": [
                        {
                            "id": "#main/gatk_intervallisttools_4_1_0_0/output_interval_list"
                        }
                    ],
                    "run": "#gatk_intervallisttools_4_1_0_0.cwl",
                    "id": "#main/gatk_intervallisttools_4_1_0_0",
                    "https://sevenbridges.comx": -584,
                    "https://sevenbridges.comy": -342
                },
                {
                    "in": [
                        {
                            "id": "#main/gatk_mergevcfs_4_1_0_0/in_variants",
                            "source": [
                                "#main/gatk_haplotypecaller_4_1_0_0/out_variants"
                            ]
                        },
                        {
                            "id": "#main/gatk_mergevcfs_4_1_0_0/output_file_format",
                            "source": "#main/output_file_format"
                        }
                    ],
                    "label": "GATK MergeVcfs",
                    "out": [
                        {
                            "id": "#main/gatk_mergevcfs_4_1_0_0/out_variants"
                        }
                    ],
                    "run": "#gatk_mergevcfs_4_1_0_0.cwl",
                    "id": "#main/gatk_mergevcfs_4_1_0_0",
                    "https://sevenbridges.comx": -156,
                    "https://sevenbridges.comy": -192
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "sbg",
                "http://xmlns.com/foaf/0.1/name": "SevenBridges",
                "http://xmlns.com/foaf/0.1/mbox": "mailto:support@sbgenomics.com"
            },
            "https://sevenbridges.comappVersion": [
                "v1.0"
            ],
            "https://sevenbridges.comcategories": [
                "Genomics",
                "Variant Calling"
            ],
            "https://sevenbridges.comcontent_hash": "a5b1fadf1920aae9697b44426ded316b073abd70545438658ba98bf40eeb95582",
            "https://sevenbridges.comcontributors": [
                "nens"
            ],
            "https://sevenbridges.comcreatedBy": "nens",
            "https://sevenbridges.comcreatedOn": 1565797611,
            "https://sevenbridges.comid": "nens/gatk-best-practice-generic-germline-short-variant-per-sample-calling-4-1-0-0-demo/gatk-best-practice-generic-germline-short-variant-per-sample-cal/6",
            "https://sevenbridges.comimage_url": "https://igor.sbgenomics.com/ns/brood/images/nens/gatk-best-practice-generic-germline-short-variant-per-sample-calling-4-1-0-0-demo/gatk-best-practice-generic-germline-short-variant-per-sample-cal/6.png",
            "https://sevenbridges.comlatestRevision": 6,
            "https://sevenbridges.comlicense": "BSD 3-Clause License",
            "https://sevenbridges.comlinks": [
                {
                    "id": "#gatk4-germline-snps-indels",
                    "label": "Homepage"
                },
                {
                    "id": "#haplotypecaller-gvcf-gatk4.wdl",
                    "label": "Source Code"
                },
                {
                    "id": "#gatk-4.1.0.0.zip",
                    "label": "Download"
                },
                {
                    "id": "#pubmed",
                    "label": "Publication"
                },
                {
                    "id": "#_3",
                    "label": "Documentation"
                }
            ],
            "https://sevenbridges.commodifiedBy": "nens",
            "https://sevenbridges.commodifiedOn": 1573052212,
            "https://sevenbridges.comproject": "nens/gatk-best-practice-generic-germline-short-variant-per-sample-calling-4-1-0-0-demo",
            "https://sevenbridges.comprojectName": "GATK Best Practice Generic germline short variant per-sample calling 4.1.0.0 - DEMO",
            "https://sevenbridges.compublisher": "sbg",
            "https://sevenbridges.comrevision": 6,
            "https://sevenbridges.comrevisionNotes": "dev v36 - with requirements for cwltool",
            "https://sevenbridges.comrevisionsInfo": [
                {
                    "https://sevenbridges.commodifiedBy": "nens",
                    "https://sevenbridges.commodifiedOn": 1565797611,
                    "https://sevenbridges.comrevision": 0,
                    "https://sevenbridges.comrevisionNotes": null
                },
                {
                    "https://sevenbridges.commodifiedBy": "nens",
                    "https://sevenbridges.commodifiedOn": 1565797659,
                    "https://sevenbridges.comrevision": 1,
                    "https://sevenbridges.comrevisionNotes": "v25 dev"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nens",
                    "https://sevenbridges.commodifiedOn": 1568624787,
                    "https://sevenbridges.comrevision": 2,
                    "https://sevenbridges.comrevisionNotes": "v32 - dev"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nens",
                    "https://sevenbridges.commodifiedOn": 1570714260,
                    "https://sevenbridges.comrevision": 3,
                    "https://sevenbridges.comrevisionNotes": "secondary files added"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nens",
                    "https://sevenbridges.commodifiedOn": 1570806429,
                    "https://sevenbridges.comrevision": 4,
                    "https://sevenbridges.comrevisionNotes": "Description update"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nens",
                    "https://sevenbridges.commodifiedOn": 1570807662,
                    "https://sevenbridges.comrevision": 5,
                    "https://sevenbridges.comrevisionNotes": "Description improved - performance benchmarking results addd"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nens",
                    "https://sevenbridges.commodifiedOn": 1573052212,
                    "https://sevenbridges.comrevision": 6,
                    "https://sevenbridges.comrevisionNotes": "dev v36 - with requirements for cwltool"
                }
            ],
            "https://sevenbridges.comsbgMaintained": false,
            "https://sevenbridges.comtoolAuthor": "Broad Institute",
            "https://sevenbridges.comvalidationErrors": [],
            "https://sevenbridges.comwrapperAuthor": "nevena.ilic.raicevic@sbgenomics.com",
            "outputs": [
                {
                    "doc": "Merged VCF file.",
                    "id": "#main/out_variants",
                    "label": "VCF file",
                    "outputSource": [
                        "#main/gatk_mergevcfs_4_1_0_0/out_variants"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comfileTypes": "VCF, VCF.GZ, BCF",
                    "https://sevenbridges.comx": 17,
                    "https://sevenbridges.comy": -190
                }
            ]
        },
        {
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--java-options"
                },
                {
                    "position": 2,
                    "prefix": "",
                    "shellQuote": false,
                    "valueFrom": "${\n    if (inputs.mem_per_job) {\n        return '\\\"-Xmx'.concat(inputs.mem_per_job, 'M') + '\\\"'\n    } else {\n        // this is required for Best Practice GATK RNA-seq workflow\n        return '\\\"-Xms6000m\\\"'\n    }\n}"
                },
                {
                    "position": 3,
                    "shellQuote": false,
                    "valueFrom": "HaplotypeCaller"
                },
                {
                    "position": 4,
                    "prefix": "--output",
                    "shellQuote": false,
                    "valueFrom": "${\n    // if output parameter is set, return output file name\n    if(inputs.output_prefix && inputs.output_extension){\n        return inputs.output_prefix + '.' + inputs.output_extension;\n    } else {\n        // determine output file extenstion\n        var out_ext;\n        if(inputs.emit_ref_confidence == 'GVCF' && inputs.output_extension){\n            out_ext = '.g.' + inputs.output_extension\n        } else {\n            out_ext = '.' + inputs.output_extension\n        }\n        var in_prefix;\n        var in_num = [].concat(inputs.in_alignments).length;\n        // create output file name if there is one input file\n        if(in_num == 1){\n            var in_align = [].concat(inputs.in_alignments)[0];\n            // check if the sample_id metadata value is defined for the input file\n            if(in_align.metadata && in_align.metadata.sample_id){\n                in_prefix = in_align.metadata.sample_id\n            // if sample_id is not defined\n            } else {\n                in_prefix = [].concat(inputs.in_alignments)[0].nameroot\n            }\n            return in_prefix + out_ext\n        }\n        // create output file name if there are more than one input files\n        else if(in_num > 1){\n            var in_align = [].concat(inputs.in_alignments);\n            var in_sample_ids = [];\n            var in_align_names = [];\n            for (var i = 0; i < in_align.length; i++) {\n                // check if the sample_id metadata value is defined for the input file\n                if(in_align[i].metadata && in_align[i].metadata.sample_id){\n                    in_sample_ids.push(in_align[i].metadata.sample_id)\n                }\n                in_align_names.push(in_align[i].nameroot)\n            }\n            if(in_sample_ids.length != 0){\n                in_prefix = in_sample_ids.sort()[0]\n            // if sample_id is not defined\n            } else {\n                in_prefix = in_align_names.sort()[0]\n            }\n            return in_prefix + '.' + in_num + out_ext\n        } else {\n            return null\n        }\n    }\n}"
                }
            ],
            "baseCommand": [
                "/opt/gatk"
            ],
            "class": "CommandLineTool",
            "doc": "Call germline single nucleotide polymorphisms (SNPs) and indels via local re-assembly of haplotypes. To call SNPs and indels, **HaplotypeCaller** requires BAM file(s) containing reads aligned to the reference genome.\n\n**HaplotypeCaller** is capable of calling SNPs and indels simultaneously via local de-novo assembly of haplotypes in an active region. In other words, whenever the program encounters a region showing signs of variation, it discards the existing mapping information and completely reassembles the reads in that region. Reassembled reads are realigned to the reference. This allows **HaplotypeCaller** to be more accurate when calling regions that are traditionally difficult to call, for example when they contain different types of variants close to each other. It also makes **HaplotypeCaller** much better at calling indels than position-based callers like UnifiedGenotyper.\n\nIn the GVCF workflow used for scalable variant calling in DNA sequence data, **HaplotypeCaller** runs per-sample to generate an intermediate GVCF (not to be used in final analysis), which can then be used in GenotypeGVCFs for joint genotyping of multiple samples in a very efficient way. The GVCF workflow enables rapid incremental processing of samples as they roll off the sequencer, as well as scaling to very large cohort sizes. \n\nIn addition, **HaplotypeCaller** is able to handle non-diploid organisms as well as pooled experiment data. Note however that the algorithms used to calculate variant likelihoods are not well suited to extreme allele frequencies (relative to ploidy) so its use is not recommended for somatic (cancer) variant discovery. For that purpose, use **Mutect2** instead.\n\nFinally, **HaplotypeCaller** is also able to correctly handle splice junctions that make RNAseq a challenge for most variant callers.\n\n*A list of **all inputs and parameters** with corresponding descriptions can be found at the bottom of this page.*\n\n### Common Use Cases\n\n- Call variants individually on each sample in GVCF mode\n\n```\n gatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.g.vcf.gz \\\n   -ERC GVCF\n```\n\n\n- Call variants individually on each sample in GVCF mode with allele-specific annotations. [Here](https://software.broadinstitute.org/gatk/documentation/article?id=9622) you can read more details about allele-specific annotation and filtering.\n\n```\ngatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.g.vcf.gz \\\n   -ERC GVCF \\\n   -G Standard \\\n   -G AS_Standard\n```\n\n\n- Call variants with [bamout](https://software.broadinstitute.org/gatk/documentation/article?id=5484) to show realigned reads. After performing a local reassembly and realignment the reads get moved to different mapping positions than what you can observe in the original BAM file. This option could be used to visualize what rearrangements **HaplotypeCaller** has made.\n\n```\n gatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.vcf.gz \\\n   -bamout bamout.bam\n```\n\n\n### Common issues and important notes\n\n- If **Read filter** (`--read-filter`) option is set to \"LibraryReadFilter\", **Library** (`--library`) option must be set to some value.\n- If **Read filter** (`--read-filter`) option is set to \"PlatformReadFilter\", **Platform filter name** (`--platform-filter-name`) option must be set to some value.\n- If **Read filter** (`--read-filter`) option is set to\"PlatformUnitReadFilter\", **Black listed lanes** (`--black-listed-lanes`) option must be set to some value. \n- If **Read filter** (`--read-filter`) option is set to \"ReadGroupBlackListReadFilter\", **Read group black list** (`--read-group-black-list`) option must be set to some value.\n- If **Read filter** (`--read-filter`) option is set to \"ReadGroupReadFilter\", **Keep read group** (`--keep-read-group`) option must be set to some value.\n- If **Read filter** (`--read-filter`) option is set to \"ReadLengthReadFilter\", **Max read length** (`--max-read-length`) option must be set to some value.\n- If **Read filter** (`--read-filter`) option is set to \"ReadNameReadFilter\", **Read name** (`--read-name`) option must be set to some value.\n- If **Read filter** (`--read-filter`) option is set to \"ReadStrandFilter\", **Keep reverse strand only** (`--keep-reverse-strand-only`) option must be set to some value.\n- If **Read filter** (`--read-filter`) option is set to \"SampleReadFilter\", **Sample** (`--sample`) option must be set to some value.\n- When working with PCR-free data, be sure to set **PCR indel model** (`--pcr_indel_model`) to NONE.\n- When running **Emit ref confidence** ( `--emit-ref-confidence`) in GVCF or in BP_RESOLUTION mode, the confidence threshold is automatically set to 0. This cannot be overridden by the command line. The threshold can be set manually to the desired level when using **GenotypeGVCFs**.\n- It is recommended to use a list of intervals to speed up the analysis. See [this document](https://software.broadinstitute.org/gatk/documentation/article?id=4133) for details.\n\n### Changes Introduced by Seven Bridges\n\n- **Include intervals** (`--intervals`) option is divided into **Include genomic intervals** and **Intervals string values** options.\n- **Exclude intervals** (`--exclude-intervals`) option is divided into **Exclude genomic intervals** and **Exclude intervals string values** options.\n- Using the **Output prefix** parameter you can set the name of the VCF output. If this value is not set the output name will be generated based on **Sample ID** metadata value from one of the input BAM files. If **Sample ID** value is not set the name will be inherited from one of the input BAM file names.\n\n### Performance Benchmarking\n\nBelow is a table describing the runtimes and task costs for a couple of samples with different file sizes.\n\n| Experiment type |  Input size | Paired-end | # of reads | Read length | Duration |  Cost (spot) | Cost (on-demand) | AWS instance type |\n|:--------------:|:------------:|:--------:|:-------:|:---------:|:----------:|:------:|:------:|:------:|\n|     RNA-Seq     | 2.6 GB |     Yes    |     16M     |     101     |   50min   | 0.22$ | 0.44$ | c4.2xlarge |\n|     RNA-Seq     | 7.7 GB |     Yes    |     50M     |     101     |   1h31min   | 0.40$ | 0.87$ | c4.2xlarge |\n|     RNA-Seq     | 12.7 GB |     Yes    |     82M    |     101     |  2h19min  | 0.61$ | 1.22$ | c4.2xlarge |\n|     RNA-Seq     | 25 GB |     Yes    |     164M    |     101     |  4h5min  | 1.07$ | 2.43 | c4.2xlarge |",
            "id": "#gatk_haplotypecaller_4_1_0_0.cwl",
            "inputs": [
                {
                    "doc": "Minimum probability for a locus to be considered active.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/active_probability_threshold",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--active-probability-threshold",
                        "shellQuote": false
                    },
                    "label": "Active probability threshold",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0.002"
                },
                {
                    "doc": "Output the raw activity profile results in IGV format.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/activity_profile_out",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--activity-profile-out",
                        "shellQuote": false
                    },
                    "label": "Activity profile output",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Use Mutect2's adaptive graph pruning algorithm.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/adaptive_pruning",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--adaptive-pruning",
                        "shellQuote": false
                    },
                    "label": "Adaptive pruning",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Initial base error rate estimate for adaptive pruning.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/adaptive_pruning_initial_error_rate",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--adaptive-pruning-initial-error-rate",
                        "shellQuote": false
                    },
                    "label": "Adaptive pruning initial error rate",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0.001"
                },
                {
                    "doc": "If true, adds a pg tag to created SAM/BAM/CRAM files.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/add_output_sam_program_record",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--add-output-sam-program-record",
                        "shellQuote": false
                    },
                    "label": "Add output SAM program record",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/add_output_sam_program_record/add_output_sam_program_record",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/add_output_sam_program_record/add_output_sam_program_record/true",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/add_output_sam_program_record/add_output_sam_program_record/false"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-add-output-sam-program-record",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "true"
                },
                {
                    "doc": "If true, adds a command line header line to created VCF files.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/add_output_vcf_command_line",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--add-output-vcf-command-line",
                        "shellQuote": false
                    },
                    "label": "Add output VCF command line",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/add_output_vcf_command_line/add_output_vcf_command_line",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/add_output_vcf_command_line/add_output_vcf_command_line/true",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/add_output_vcf_command_line/add_output_vcf_command_line/false"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-add-output-vcf-command-line",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "true"
                },
                {
                    "doc": "Annotate all sites with PLs.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/all_site_pls",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--all-site-pls",
                        "shellQuote": false
                    },
                    "label": "Annotate all sites with PLs",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "The set of alleles at which to genotype when --genotyping_mode is genotype_given_alleles.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/alleles",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--alleles",
                        "shellQuote": false
                    },
                    "label": "Alleles",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "BCF2, VCF, VCF3",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Allow graphs that have non-unique kmers in the reference.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/allow_non_unique_kmers_in_ref",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--allow-non-unique-kmers-in-ref",
                        "shellQuote": false
                    },
                    "label": "Allow non unique kmers in ref",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "If provided, we will annotate records with the number of alternate alleles that were discovered (but not necessarily genotyped) at a given site.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotate_with_num_discovered_alleles",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--annotate-with-num-discovered-alleles",
                        "shellQuote": false
                    },
                    "label": "Annotate with num discovered alleles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "One or more specific annotations to add to variant calls.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation",
                    "inputBinding": {
                        "itemSeparator": "null",
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--annotation ' + self.join(' --annotation ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Annotation",
                    "type": [
                        "null",
                        {
                            "items": {
                                "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation",
                                "symbols": [
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AlleleFraction",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AS_BaseQualityRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AS_FisherStrand",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AS_InbreedingCoeff",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AS_MappingQualityRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AS_QualByDepth",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AS_ReadPosRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AS_RMSMappingQuality",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/AS_StrandOddsRatio",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/BaseQuality",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/BaseQualityRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/ChromosomeCounts",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/ClippingRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/CountNs",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/Coverage",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/DepthPerAlleleBySample",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/DepthPerSampleHC",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/ExcessHet",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/FisherStrand",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/FragmentLength",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/GenotypeSummaries",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/InbreedingCoeff",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/LikelihoodRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/MappingQuality",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/MappingQualityRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/MappingQualityZero",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/OriginalAlignment",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/OxoGReadCounts",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/PolymorphicNuMT",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/PossibleDeNovo",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/QualByDepth",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/ReadOrientationArtifact",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/ReadPosition",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/ReadPosRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/ReferenceBases",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/RMSMappingQuality",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/SampleList",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/StrandArtifact",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/StrandBiasBySample",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/StrandOddsRatio",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/TandemRepeat",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation/annotation/UniqueAltReadCount"
                                ],
                                "type": "enum"
                            },
                            "type": "array"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-A",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "One or more groups of annotations to apply to variant calls.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation_group",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--annotation-group ' + self.join(' --annotation-group ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Annotation group",
                    "type": [
                        "null",
                        {
                            "items": {
                                "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation_group/annotation_group",
                                "symbols": [
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation_group/annotation_group/AS_StandardAnnotation",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation_group/annotation_group/OrientationBiasMixtureModelAnnotation",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation_group/annotation_group/ReducibleAnnotation",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation_group/annotation_group/StandardAnnotation",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation_group/annotation_group/StandardHCAnnotation",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotation_group/annotation_group/StandardMutectAnnotation"
                                ],
                                "type": "enum"
                            },
                            "type": "array"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-G",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "One or more specific annotations to exclude from variant calls.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--annotations-to-exclude ' + self.join(' --annotations-to-exclude ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Annotations to exclude",
                    "type": [
                        "null",
                        {
                            "items": {
                                "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude",
                                "symbols": [
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/BaseQualityRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/ChromosomeCounts",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/Coverage",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/DepthPerAlleleBySample",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/DepthPerSampleHC",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/ExcessHet",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/FisherStrand",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/InbreedingCoeff",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/MappingQualityRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/QualByDepth",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/ReadPosRankSumTest",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/RMSMappingQuality",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/annotations_to_exclude/annotations_to_exclude/StrandOddsRatio"
                                ],
                                "type": "enum"
                            },
                            "type": "array"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-AX",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Read one or more arguments files and add them to the command line.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/arguments_file",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        var cmd = '';\n        for (var i=0; i<self.length; i++) {\n            cmd += ' --arguments_file ' + self[i].path\n        }\n        return cmd\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Arguments",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "TXT",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Output the assembly region to this IGV formatted file.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/assembly_region_out",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--assembly-region-out",
                        "shellQuote": false
                    },
                    "label": "Assembly region output",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Number of additional bases of context to include around each assembly region.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/assembly_region_padding",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--assembly-region-padding",
                        "shellQuote": false
                    },
                    "label": "Assembly region padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "100"
                },
                {
                    "doc": "File to which assembled haplotypes should be written.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/bam_output",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--bam-output",
                        "shellQuote": false
                    },
                    "label": "BAM output",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comaltPrefix": "-bamout",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Which haplotypes should be written to the BAM.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/bam_writer_type",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--bam-writer-type",
                        "shellQuote": false
                    },
                    "label": "BAM writer type",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/bam_writer_type/bam_writer_type",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/bam_writer_type/bam_writer_type/ALL_POSSIBLE_HAPLOTYPES",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/bam_writer_type/bam_writer_type/CALLED_HAPLOTYPES"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "CALLED_HAPLOTYPES"
                },
                {
                    "doc": "Base qualities below this threshold will be reduced to the minimum (6).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/base_quality_score_threshold",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--base-quality-score-threshold",
                        "shellQuote": false
                    },
                    "label": "Base quality score threshold",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "18"
                },
                {
                    "doc": "Comparison vcf file(s).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/comp",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        var cmd = '';\n        for (var i=0; i<self.length; i++) {\n            cmd += ' --comp ' + self[i].path\n        }\n        return cmd\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Comparison VCF",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-comp",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comfileTypes": "VCF",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "1000g consensus mode.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/consensus",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--consensus",
                        "shellQuote": false
                    },
                    "label": "Consensus",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Tab-separated file containing fraction of contamination in sequencing data (per sample) to aggressively remove. Format should be \".",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/contamination_fraction_per_sample_file",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--contamination-fraction-per-sample-file",
                        "shellQuote": false
                    },
                    "label": "Contamination fraction per sample",
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comaltPrefix": "-contamination-file",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comfileTypes": "TSV"
                },
                {
                    "doc": "Fraction of contamination in sequencing data (for all samples) to aggressively remove 0.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/contamination_fraction_to_filter",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--contamination-fraction-to-filter",
                        "shellQuote": false
                    },
                    "label": "Contamination fraction to filter",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comaltPrefix": "-contamination",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0"
                },
                {
                    "doc": "Undocumented option.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/correct_overlapping_quality",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--correct-overlapping-quality",
                        "shellQuote": false
                    },
                    "label": "Correct overlapping quality",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "If true, create a BAM/CRAM index when writing a coordinate-sorted BAM/CRAM file.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_bam_index",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--create-output-bam-index",
                        "shellQuote": false
                    },
                    "label": "Create output BAM index",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_bam_index/create_output_bam_index",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_bam_index/create_output_bam_index/true",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_bam_index/create_output_bam_index/false"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-OBI",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "true"
                },
                {
                    "doc": "If true, create a md5 digest for any BAM/SAM/CRAM file created.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_bam_md5",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--create-output-bam-md5",
                        "shellQuote": false
                    },
                    "label": "Create output BAM md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-OBM",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "If true, create a vcf index when writing a coordinate-sorted VCF file.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_variant_index",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--create-output-variant-index",
                        "shellQuote": false
                    },
                    "label": "Create output variant index",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_variant_index/create_output_variant_index",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_variant_index/create_output_variant_index/true",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_variant_index/create_output_variant_index/false"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-OVI",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "true"
                },
                {
                    "doc": "If true, create a a md5 digest any VCF file created.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/create_output_variant_md5",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--create-output-variant-md5",
                        "shellQuote": false
                    },
                    "label": "Create output variant md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-OVM",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "dbSNP file.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/dbsnp",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--dbsnp",
                        "shellQuote": false
                    },
                    "label": "dbSNP",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comaltPrefix": "-D",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "VCF",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Print out very verbose debug information about each triggering active region.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/debug",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--debug",
                        "shellQuote": false
                    },
                    "label": "Debug",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-debug",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "If true, don't cache BAM indexes, this will reduce memory requirements but may harm performance if many intervals are specified. Caching is automatically disabled if there are no intervals specified.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_bam_index_caching",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--disable-bam-index-caching",
                        "shellQuote": false
                    },
                    "label": "Disable BAM index caching",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-DBIC",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Don't skip calculations in activeregions with no variants.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_optimizations",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--disable-optimizations",
                        "shellQuote": false
                    },
                    "label": "Disable optimizations",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Read filters to be disabled before analysis.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--disable-read-filter ' + self.join(' --disable-read-filter ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Disable read filter",
                    "type": [
                        "null",
                        {
                            "items": {
                                "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter",
                                "symbols": [
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/GoodCigarReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/MappedReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/MappingQualityAvailableReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/MappingQualityReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/NonZeroReferenceLengthAlignmentReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/NotDuplicateReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/NotSecondaryAlignmentReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/PassesVendorQualityCheckReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_read_filter/disable_read_filter/WellformedReadFilter"
                                ],
                                "type": "enum"
                            },
                            "type": "array"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-DF",
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "If specified, do not check the sequence dictionaries from our inputs for compatibility. Use at your own risk!",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_sequence_dictionary_validation",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--disable-sequence-dictionary-validation",
                        "shellQuote": false
                    },
                    "label": "Disable sequence dictionary validation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-disable-sequence-dictionary-validation",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Disable all tool default annotations.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_tool_default_annotations",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--disable-tool-default-annotations",
                        "shellQuote": false
                    },
                    "label": "Disable tool default annotations",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-disable-tool-default-annotations",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Disable all tool default read filters (warning: many tools will not function correctly without their default read filters on).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/disable_tool_default_read_filters",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--disable-tool-default-read-filters",
                        "shellQuote": false
                    },
                    "label": "Disable tool default read filters",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-disable-tool-default-read-filters",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Disable physical phasing.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/do_not_run_physical_phasing",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--do-not-run-physical-phasing",
                        "shellQuote": false
                    },
                    "label": "Do not run physical phasing",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Disable iterating over kmer sizes when graph cycles are detected.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/dont_increase_kmer_sizes_for_cycles",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--dont-increase-kmer-sizes-for-cycles",
                        "shellQuote": false
                    },
                    "label": "Dont increase kmer sizes for cycles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "If specified, we will not trim down the active region from the full region (active + extension) to just the active interval for genotyping.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/dont_trim_active_regions",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--dont-trim-active-regions",
                        "shellQuote": false
                    },
                    "label": "Dont trim active regions",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Do not analyze soft clipped bases in the reads.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/dont_use_soft_clipped_bases",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--dont-use-soft-clipped-bases",
                        "shellQuote": false
                    },
                    "label": "Do not use soft clipped bases",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Mode for emitting reference confidence scores.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/emit_ref_confidence",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--emit-ref-confidence",
                        "shellQuote": false
                    },
                    "label": "Emit ref confidence",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/emit_ref_confidence/emit_ref_confidence",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/emit_ref_confidence/emit_ref_confidence/NONE",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/emit_ref_confidence/emit_ref_confidence/BP_RESOLUTION",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/emit_ref_confidence/emit_ref_confidence/GVCF"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-ERC",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "NONE"
                },
                {
                    "doc": "Use all possible annotations (not for the faint of heart).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/enable_all_annotations",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--enable-all-annotations",
                        "shellQuote": false
                    },
                    "label": "Enable all annotations",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "One or more genomic intervals to exclude from processing.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/exclude_intervals_string",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--exclude-intervals ' + self.join(' --exclude-intervals ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Exclude intervals string values",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-XL",
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Samples representing the population \"founders\".",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/founder_id",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--founder-id ' + self.join(' --founder-id ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Founder id",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-founder-id",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "A configuration file to use with the GATK.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/gatk_config_file",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--gatk-config-file",
                        "shellQuote": false
                    },
                    "label": "GATK config",
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "TXT",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "If the GCS bucket channel errors out, how many times it will attempt to re-initiate the connection.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/gcs_max_retries",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--gcs-max-retries",
                        "shellQuote": false
                    },
                    "label": "GCS max retries",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comaltPrefix": "-gcs-retries",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "20"
                },
                {
                    "doc": "Project to bill when accessing \"requester pays\" buckets. If unset, these buckets cannot be accessed. Default value: .",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/gcs_project_for_requester_pays",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--gcs-project-for-requester-pays",
                        "shellQuote": false
                    },
                    "label": "GCS project for requester pays",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Whether to genotype all given alleles, even filtered ones, --genotyping_mode is genotype_given_alleles.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/genotype_filtered_alleles",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--genotype-filtered-alleles",
                        "shellQuote": false
                    },
                    "label": "Genotype filtered alleles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Specifies how to determine the alternate alleles to use for genotyping.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/genotyping_mode",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--genotyping-mode",
                        "shellQuote": false
                    },
                    "label": "Genotyping mode",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/genotyping_mode/genotyping_mode",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/genotyping_mode/genotyping_mode/DISCOVERY",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/genotyping_mode/genotyping_mode/GENOTYPE_GIVEN_ALLELES"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "DISCOVERY"
                },
                {
                    "doc": "Write debug assembly graph information to this file.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/graph_output",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--graph-output",
                        "shellQuote": false
                    },
                    "label": "Graph output",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comaltPrefix": "-graph",
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Exclusive upper bounds for reference confidence GQ bands (must be value from 1 to 100 and specified in increasing order).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/gvcf_gq_bands",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--gvcf-gq-bands ' + self.join(' --gvcf-gq-bands ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "GVCF GQ bands",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-GQB",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 70, 80, 90, 99"
                },
                {
                    "doc": "Heterozygosity value used to compute prior likelihoods for any locus. See the gatkdocs for full details on the meaning of this population genetics concept.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/heterozygosity",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--heterozygosity",
                        "shellQuote": false
                    },
                    "label": "Heterozygosity",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0.001"
                },
                {
                    "doc": "Standard deviation of heterozygosity for SNP and indel calling.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/heterozygosity_stdev",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--heterozygosity-stdev",
                        "shellQuote": false
                    },
                    "label": "Heterozygosity stdev",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0.01"
                },
                {
                    "doc": "Heterozygosity for indel calling. See the gatkdocs for heterozygosity for full details on the meaning of this population genetics concept.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/indel_heterozygosity",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--indel-heterozygosity",
                        "shellQuote": false
                    },
                    "label": "Indel heterozygosity",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "1.25E-4"
                },
                {
                    "doc": "The size of an indel to check for in the reference model.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/indel_size_to_eliminate_in_ref_model",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--indel-size-to-eliminate-in-ref-model",
                        "shellQuote": false
                    },
                    "label": "Indel size to eliminate in ref model",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "10"
                },
                {
                    "doc": "BAM/SAM/CRAM file containing reads this argument must be specified at least once.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/in_alignments",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    var in_files = [].concat(inputs.in_alignments);\n    if (in_files) {\n        var cmd = '';\n        for (var i=0; i<in_files.length; i++) {\n            cmd += ' --input ' + in_files[i].path\n        }\n        return cmd\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Input alignments",
                    "secondaryFiles": [
                        "${ \n    if(self.nameext == '.bam'){\n    return self.nameroot + \".bai\";\n    }\n    else if(self.nameext == '.cram'){\n    return self.nameroot + \".crai\";\n    } else {\n    return null;\n    }\n}"
                    ],
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "https://sevenbridges.comaltPrefix": "-I",
                    "https://sevenbridges.comcategory": "Required Arguments",
                    "https://sevenbridges.comfileTypes": "BAM, SAM, CRAM"
                },
                {
                    "doc": "Input prior for calls.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/input_prior",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--input-prior ' + self.join(' --input-prior ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Input prior",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "float"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments"
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are excluding.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_exclusion_padding",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--interval-exclusion-padding",
                        "shellQuote": false
                    },
                    "label": "Interval exclusion padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comaltPrefix": "-ixp",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0"
                },
                {
                    "doc": "Interval merging rule for abutting intervals.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_merging_rule",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--interval-merging-rule",
                        "shellQuote": false
                    },
                    "label": "Interval merging rule",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_merging_rule/interval_merging_rule",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_merging_rule/interval_merging_rule/ALL",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_merging_rule/interval_merging_rule/OVERLAPPING_ONLY"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-imr",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "ALL"
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are including.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_padding",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--interval-padding",
                        "shellQuote": false
                    },
                    "label": "Interval padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comaltPrefix": "-ip",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0"
                },
                {
                    "doc": "Set merging approach to use for combining interval inputs.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_set_rule",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--interval-set-rule",
                        "shellQuote": false
                    },
                    "label": "Interval set rule",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_set_rule/interval_set_rule",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_set_rule/interval_set_rule/UNION",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/interval_set_rule/interval_set_rule/INTERSECTION"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-isr",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "UNION"
                },
                {
                    "doc": "One or more genomic intervals over which to operate.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/include_intervals",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--intervals",
                        "shellQuote": false
                    },
                    "label": "Include genomic intervals",
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comaltPrefix": "-L",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "INTERVAL_LIST",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "One or more genomic intervals over which to operate.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/include_intervals_string",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--intervals ' + self.join(' --intervals ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Intervals string values",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-L",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Kmer size to use in the read threading assembler.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/kmer_size",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--kmer-size ' + self.join(' --kmer-size ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Kmer size",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "10, 25"
                },
                {
                    "doc": "Lenient processing of VCF files.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/lenient",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--lenient",
                        "shellQuote": false
                    },
                    "label": "Lenient",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-LE",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Maximum number of alternate alleles to genotype.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_alternate_alleles",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--max-alternate-alleles",
                        "shellQuote": false
                    },
                    "label": "Max alternate alleles",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "6"
                },
                {
                    "doc": "Maximum size of an assembly region.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_assembly_region_size",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--max-assembly-region-size",
                        "shellQuote": false
                    },
                    "label": "Max assembly region size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "300"
                },
                {
                    "doc": "Maximum number of genotypes to consider at any site.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_genotype_count",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--max-genotype-count",
                        "shellQuote": false
                    },
                    "label": "Max genotype count",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "1024"
                },
                {
                    "doc": "Two or more phased substitutions separated by this distance or less are merged into MNPs. Warning: when used in GVCF mode, resulting GVCFs cannot be joint-genotyped.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_mnp_distance",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--max-mnp-distance",
                        "shellQuote": false
                    },
                    "label": "Max MNP distance",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comaltPrefix": "-mnp-dist",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0"
                },
                {
                    "doc": "Maximum number of haplotypes to consider for your population.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_num_haplotypes_in_population",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--max-num-haplotypes-in-population",
                        "shellQuote": false
                    },
                    "label": "Max num haplotypes in population",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "128"
                },
                {
                    "doc": "Upper limit on how many bases away probability mass can be moved around when calculating the boundaries between active and inactive assembly regions.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_prob_propagation_distance",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--max-prob-propagation-distance",
                        "shellQuote": false
                    },
                    "label": "Max prob propagation distance",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "50"
                },
                {
                    "doc": "Maximum number of reads to retain per alignment start position. Reads above this threshold will be downsampled. Set to 0 to disable.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_reads_per_alignment_start",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--max-reads-per-alignment-start",
                        "shellQuote": false
                    },
                    "label": "Max reads per alignment start",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "50"
                },
                {
                    "doc": "Maximum number of variants in graph the adaptive pruner will allow.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_unpruned_variants",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--max-unpruned-variants",
                        "shellQuote": false
                    },
                    "label": "Max unpruned variants",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "100"
                },
                {
                    "doc": "Valid only if \"MappingQualityReadFilter\" is specified:\nMaximum mapping quality to keep (inclusive).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/maximum_mapping_quality",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--maximum-mapping-quality",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"MappingQualityReadFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Maximum mapping quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Memory overhead per job. By default this parameter value is set to '0' (zero megabytes). This parameter value is added to the Memory per job parameter value. This results in the allocation of the sum total (Memory per job and Memory overhead per job) amount of memory per job. By default the memory per job parameter value is set to 2048 megabytes, unless specified otherwise.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/mem_overhead_per_job",
                    "label": "Memory overhead per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform options"
                },
                {
                    "doc": "Amount of RAM memory to be used per job. Defaults to 2048MB for Single threaded jobs,and all of the available memory on the instance for multi-threaded jobs.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/mem_per_job",
                    "label": "Memory per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform options",
                    "https://sevenbridges.comtoolDefaultValue": "2048"
                },
                {
                    "doc": "Minimum size of an assembly region.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/min_assembly_region_size",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--min-assembly-region-size",
                        "shellQuote": false
                    },
                    "label": "Min assembly region size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "50"
                },
                {
                    "doc": "Minimum base quality required to consider a base for calling.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/min_base_quality_score",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--min-base-quality-score",
                        "shellQuote": false
                    },
                    "label": "Min base quality score",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comaltPrefix": "-mbq",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "10"
                },
                {
                    "doc": "Minimum length of a dangling branch to attempt recovery.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/min_dangling_branch_length",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--min-dangling-branch-length",
                        "shellQuote": false
                    },
                    "label": "Min dangling branch length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "4"
                },
                {
                    "doc": "Minimum support to not prune paths in the graph.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/min_pruning",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--min-pruning",
                        "shellQuote": false
                    },
                    "label": "Min pruning",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "2"
                },
                {
                    "doc": "Valid only if \"MappingQualityReadFilter\" is specified:\nMinimum mapping quality to keep (inclusive).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/minimum_mapping_quality",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--minimum-mapping-quality",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"MappingQualityReadFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Minimum mapping quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "20"
                },
                {
                    "doc": "How many threads should a native pairHMM implementation use.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/native_pair_hmm_threads",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--native-pair-hmm-threads",
                        "shellQuote": false
                    },
                    "label": "Native pairHMM threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "4"
                },
                {
                    "doc": "Use double precision in the native pairHMM. This is slower but matches the java implementation better.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/native_pair_hmm_use_double_precision",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--native-pair-hmm-use-double-precision",
                        "shellQuote": false
                    },
                    "label": "Native pairHMM use double precision",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Number of samples that must pass the minPruning threshold.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/num_pruning_samples",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--num-pruning-samples",
                        "shellQuote": false
                    },
                    "label": "Num pruning samples",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "1"
                },
                {
                    "doc": "Number of hom-ref genotypes to infer at sites not present in a panel.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/num_reference_samples_if_no_call",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--num-reference-samples-if-no-call",
                        "shellQuote": false
                    },
                    "label": "Num reference samples if no call",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0"
                },
                {
                    "doc": "Output prefix.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_prefix",
                    "label": "Output prefix",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comaltPrefix": "-O",
                    "https://sevenbridges.comcategory": "Required Arguments"
                },
                {
                    "doc": "Specifies which type of calls are contained output.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_mode",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--output-mode",
                        "shellQuote": false
                    },
                    "label": "Output mode",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_mode/output_mode",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_mode/output_mode/EMIT_VARIANTS_ONLY",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_mode/output_mode/EMIT_ALL_CONFIDENT_SITES",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_mode/output_mode/EMIT_ALL_SITES"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "EMIT_VARIANTS_ONLY"
                },
                {
                    "doc": "Flat gap continuation penalty for use in the pairHMM.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_gap_continuation_penalty",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--pair-hmm-gap-continuation-penalty",
                        "shellQuote": false
                    },
                    "label": "Pair HMM gap continuation penalty",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "10"
                },
                {
                    "doc": "The pairHMM implementation to use for genotype likelihood calculations.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--pair-hmm-implementation",
                        "shellQuote": false
                    },
                    "label": "Pair HMM implementation",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation/pair_hmm_implementation",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation/pair_hmm_implementation/EXACT",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation/pair_hmm_implementation/ORIGINAL",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation/pair_hmm_implementation/LOGLESS_CACHING",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation/pair_hmm_implementation/AVX_LOGLESS_CACHING",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation/pair_hmm_implementation/AVX_LOGLESS_CACHING_OMP",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation/pair_hmm_implementation/EXPERIMENTAL_FPGA_LOGLESS_CACHING",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pair_hmm_implementation/pair_hmm_implementation/FASTEST_AVAILABLE"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-pairHMM",
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "FASTEST_AVAILABLE"
                },
                {
                    "doc": "The PCR indel model to use.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pcr_indel_model",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--pcr-indel-model",
                        "shellQuote": false
                    },
                    "label": "PCR indel model",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pcr_indel_model/pcr_indel_model",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pcr_indel_model/pcr_indel_model/NONE",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pcr_indel_model/pcr_indel_model/HOSTILE",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pcr_indel_model/pcr_indel_model/AGGRESSIVE",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pcr_indel_model/pcr_indel_model/CONSERVATIVE"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "CONSERVATIVE"
                },
                {
                    "doc": "Pedigree file for determining the population \"founders\".",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pedigree",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--pedigree",
                        "shellQuote": false
                    },
                    "label": "Pedigree",
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comaltPrefix": "-ped",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "PED",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "The global assumed mismapping rate for reads.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/phred_scaled_global_read_mismapping_rate",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--phred-scaled-global-read-mismapping-rate",
                        "shellQuote": false
                    },
                    "label": "Phred scaled global read mismapping rate",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "45"
                },
                {
                    "doc": "Callset to use in calculating genotype priors.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/population_callset",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--population-callset",
                        "shellQuote": false
                    },
                    "label": "Population callset",
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comaltPrefix": "-population",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "VCF",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Log-10 likelihood ratio threshold for adaptive pruning algorithm.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/pruning_lod_threshold",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--pruning-lod-threshold",
                        "shellQuote": false
                    },
                    "label": "Pruning lod threshold",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "1.0"
                },
                {
                    "doc": "Read filters to be applied before analysis.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--read-filter ' + self.join(' --read-filter ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Read filter",
                    "type": [
                        "null",
                        {
                            "items": {
                                "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter",
                                "symbols": [
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/AlignmentAgreesWithHeaderReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/AllowAllReadsReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/AmbiguousBaseReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/CigarContainsNoNOperator",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/FirstOfPairReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/FragmentLengthReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/GoodCigarReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/HasReadGroupReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/LibraryReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/MappedReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/MappingQualityAvailableReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/MappingQualityNotZeroReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/MappingQualityReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/MatchingBasesAndQualsReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/MateDifferentStrandReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/MateOnSameContigOrNoMappedMateReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/MetricsReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/NonChimericOriginalAlignmentReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/NonZeroFragmentLengthReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/NonZeroReferenceLengthAlignmentReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/NotDuplicateReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/NotOpticalDuplicateReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/NotSecondaryAlignmentReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/NotSupplementaryAlignmentReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/OverclippedReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/PairedReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/PassesVendorQualityCheckReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/PlatformReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/PlatformUnitReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/PrimaryLineReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ProperlyPairedReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ReadGroupBlackListReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ReadGroupReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ReadLengthEqualsCigarLengthReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ReadLengthReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ReadNameReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ReadStrandFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/SampleReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/SecondOfPairReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/SeqIsStoredReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ValidAlignmentEndReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/ValidAlignmentStartReadFilter",
                                    "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_filter/read_filter/WellformedReadFilter"
                                ],
                                "type": "enum"
                            },
                            "type": "array"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-RF",
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Indices to use for the read inputs. If specified, an index must be provided for every read input and in the same order as the read inputs. If this argument is not specified, the path to the index for each input will be inferred automatically.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_index",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self) {\n        return '--read-index ' + self.join(' --read-index ')\n    } else {\n        return null\n    }\n}"
                    },
                    "label": "Read index",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-read-index",
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Validation stringency for all SAM/BAM/CRAM/SRA files read by this program. The default stringency value silent can improve performance when processing a bam file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_validation_stringency",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--read-validation-stringency",
                        "shellQuote": false
                    },
                    "label": "Read validation stringency",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_validation_stringency/read_validation_stringency",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_validation_stringency/read_validation_stringency/STRICT",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_validation_stringency/read_validation_stringency/LENIENT",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_validation_stringency/read_validation_stringency/SILENT"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-VS",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "SILENT"
                },
                {
                    "doc": "This argument is deprecated since version 3.3.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/recover_dangling_heads",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--recover-dangling-heads",
                        "shellQuote": false
                    },
                    "label": "Recover dangling heads",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Reference sequence file.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/in_reference",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--reference",
                        "shellQuote": false
                    },
                    "label": "Reference",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "type": "File",
                    "https://sevenbridges.comaltPrefix": "-R",
                    "https://sevenbridges.comcategory": "Required Arguments",
                    "https://sevenbridges.comfileTypes": "FASTA, FA",
                    "https://sevenbridges.comtoolDefaultValue": "FASTA, FA"
                },
                {
                    "doc": "Name of single sample to use from a multi-sample bam.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/sample_name",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--sample-name",
                        "shellQuote": false
                    },
                    "label": "Sample name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comaltPrefix": "-ALIAS",
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Ploidy (number of chromosomes) per sample. For pooled data, set to (number of samples in each pool x Sample Ploidy).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/sample_ploidy",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--sample-ploidy",
                        "shellQuote": false
                    },
                    "label": "Sample ploidy",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comaltPrefix": "-ploidy",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "2"
                },
                {
                    "doc": "Output traversal statistics every time this many seconds elapse.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/seconds_between_progress_updates",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--seconds-between-progress-updates",
                        "shellQuote": false
                    },
                    "label": "Seconds between progress updates",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comaltPrefix": "-seconds-between-progress-updates",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "10.0"
                },
                {
                    "doc": "Use the given sequence dictionary as the master/canonical sequence dictionary. Must be a .dict file.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/sequence_dictionary",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--sequence-dictionary",
                        "shellQuote": false
                    },
                    "label": "Sequence dictionary",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comaltPrefix": "-sequence-dictionary",
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "If true, don't emit genotype fields when writing VCF file output.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/sites_only_vcf_output",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--sites-only-vcf-output",
                        "shellQuote": false
                    },
                    "label": "Sites only VCF output",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Which Smith-Waterman implementation to use, generally FASTEST_AVAILABLE is the right choice.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/smith_waterman",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--smith-waterman",
                        "shellQuote": false
                    },
                    "label": "Smith waterman",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/smith_waterman/smith_waterman",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/smith_waterman/smith_waterman/FASTEST_AVAILABLE",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/smith_waterman/smith_waterman/AVX_ENABLED",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/smith_waterman/smith_waterman/JAVA"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "JAVA"
                },
                {
                    "doc": "The minimum phred-scaled confidence threshold at which variants should be called.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/standard_min_confidence_threshold_for_calling",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--standard-min-confidence-threshold-for-calling",
                        "shellQuote": false
                    },
                    "label": "Standard min confidence threshold for calling",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comaltPrefix": "-stand-call-conf",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "30.0"
                },
                {
                    "doc": "Temporary directory to use.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/tmp_dir",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--tmp-dir",
                        "shellQuote": false
                    },
                    "label": "Tmp dir",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Use additional trigger on variants found in an external alleles file.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_alleles_trigger",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--use-alleles-trigger",
                        "shellQuote": false
                    },
                    "label": "Use alleles trigger",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Use the contamination-filtered read maps for the purposes of annotating variants.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_filtered_reads_for_annotations",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--use-filtered-reads-for-annotations",
                        "shellQuote": false
                    },
                    "label": "Use filtered reads for annotations",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Advanced Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_jdk_deflater",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--use-jdk-deflater",
                        "shellQuote": false
                    },
                    "label": "Use JdkDeflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-jdk-deflater",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Whether to use the jdkinflater (as opposed to IntelInflater).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_jdk_inflater",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--use-jdk-inflater",
                        "shellQuote": false
                    },
                    "label": "Use JdkInflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-jdk-inflater",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Use the new AF model instead of the so-called exact model.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_new_qual_calculator",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--use-new-qual-calculator",
                        "shellQuote": false
                    },
                    "label": "Use new qual calculator",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_new_qual_calculator/use_new_qual_calculator",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_new_qual_calculator/use_new_qual_calculator/true",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_new_qual_calculator/use_new_qual_calculator/false"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-new-qual",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "true"
                },
                {
                    "doc": "Use the old AF model.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/use_old_qual_calculator",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--use-old-qual-calculator",
                        "shellQuote": false
                    },
                    "label": "Use old qual calculator",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comaltPrefix": "-old-qual",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Control verbosity of logging.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/verbosity",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--verbosity",
                        "shellQuote": false
                    },
                    "label": "Verbosity",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/verbosity/verbosity",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/verbosity/verbosity/ERROR",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/verbosity/verbosity/WARNING",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/verbosity/verbosity/INFO",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/verbosity/verbosity/DEBUG"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-verbosity",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "INFO"
                },
                {
                    "doc": "One or more genomic intervals to exclude from processing.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/exclude_intervals_file",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--exclude-intervals",
                        "shellQuote": false
                    },
                    "label": "Exclude genomic intervals",
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comaltPrefix": "-XL",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "INTERVAL_LIST"
                },
                {
                    "doc": "Number of CPUs to be used per job.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/cpu_per_job",
                    "label": "CPU per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform options",
                    "https://sevenbridges.comtoolDefaultValue": "1"
                },
                {
                    "doc": "Valid only if \"AmbiguousBaseReadFilter\" is specified:\nThreshold number of ambiguous bases. If null, uses threshold fraction; otherwise, overrides threshold fraction. Cannot be used in conjuction with argument(s) maxAmbiguousBaseFraction.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/ambig_filter_bases",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--ambig-filter-bases",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"AmbiguousBaseReadFilter\") != -1 &&\n        inputs.read_filter.indexOf(\"maxAmbiguousBaseFraction\") == -1){\n            return self\n        }\n    }\n}\n"
                    },
                    "label": "Ambig filter bases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Valid only if \"AmbiguousBaseReadFilter\" is specified:\nThreshold fraction of ambiguous bases. Cannot be used in conjuction with argument(s) maxAmbiguousBases.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/ambig_filter_frac",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--ambig-filter-frac",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"AmbiguousBaseReadFilter\") != -1 &&\n        inputs.read_filter.indexOf(\"maxAmbiguousBases\") == -1){\n            return self\n        }\n    }\n}\n"
                    },
                    "label": "Ambig filter frac",
                    "type": [
                        "null",
                        "float"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option",
                    "https://sevenbridges.comtoolDefaultValue": "0.05"
                },
                {
                    "doc": "Valid only if \"FragmentLengthReadFilter\" is specified:\nMaximum length of fragment (insert size).",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_fragment_length",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--max-fragment-length",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"FragmentLengthReadFilter\") != -1){\n            return self\n        }\n    }\n}\n"
                    },
                    "label": "Max fragment length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option",
                    "https://sevenbridges.comtoolDefaultValue": "1000000"
                },
                {
                    "doc": "Valid only if \"LibraryReadFilter\" is specified:\nName of the library to keep. This argument must be specified at least once.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/library",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter && inputs.read_filter.indexOf(\"LibraryReadFilter\") != -1){\n            return '--library ' + self.join(' --library ')\n        } else {\n            return null\n        }\n}\n\n"
                    },
                    "label": "Library",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Valid only if \"OverclippedReadFilter\" is specified:\nAllow a read to be filtered out based on having only 1 soft-clipped block. By default, both ends must have a soft-clipped block, setting this flag requires only 1 soft-clipped block.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/dont_require_soft_clips_both_ends",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--dont-require-soft-clips-both-ends",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"OverclippedReadFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Do not require soft clips",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Valid only if \"OverclippedReadFilter\" is specified:\nMinimum number of aligned bases.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/filter_too_short",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--filter-too-short",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"OverclippedReadFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Filter too short",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option",
                    "https://sevenbridges.comtoolDefaultValue": "30"
                },
                {
                    "doc": "Valid only if \"PlatformReadFilter\" is specified:\nPlatform attribute (PL) to match.  This argument must be specified at least once.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/platform_filter_name",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter && inputs.read_filter.indexOf(\"PlatformReadFilter\") != -1){\n        return \"--platform-filter-name \" + self.join(' --platform-filter-name ')\n    } else {\n        return null\n    }\n}\n\n"
                    },
                    "label": "Platform filter name",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Valid only if \"PlatformUnitReadFilter\" is specified:\nPlatform unit (PU) to filter out. This argument must be specified at least once.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/black_listed_lanes",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter && inputs.read_filter.indexOf(\"PlatformUnitReadFilter\") != -1){\n            return \"--black-listed-lanes \" + self.join(' --black-listed-lanes ')\n    } else {\n        return null\n    }\n}\n\n"
                    },
                    "label": "Black listed lanes",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Valid only if \"ReadGroupBlackListReadFilter\" is specified:\nThe name of the read group to filter out. This argument must be specified at least once.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_group_black_list",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter && inputs.read_filter.indexOf(\"ReadGroupBlackListReadFilter\") != -1){\n            return \"--read-group-black-list \" + self.join(' --read-group-black-list ')\n    } else {\n        return null\n    }\n}\n\n"
                    },
                    "label": "Read group black list",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Valid only if \"ReadGroupReadFilter\" is specified:\nThe name of the read group to keep.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/keep_read_group",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--keep-read-group",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"ReadGroupReadFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Keep read group",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Valid only if \"ReadLengthReadFilter\" is specified:\nKeep only reads with length at most equal to the specified value.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/max_read_length",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--max-read-length",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"ReadLengthReadFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Max read length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Valid only if \"ReadLengthReadFilter\" is specified:\nKeep only reads with length at least equal to the specified value.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/min_read_length",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--min-read-length",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"ReadLengthReadFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Min read length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option",
                    "https://sevenbridges.comtoolDefaultValue": "1"
                },
                {
                    "doc": "Valid only if \"ReadNameReadFilter\" is specified:\nKeep only reads with this read name.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/read_name",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--read-name",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"ReadNameReadFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Read name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "doc": "Valid only if \"ReadStrandFilter\" is specified:\nKeep only reads on the reverse strand.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/keep_reverse_strand_only",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--keep-reverse-strand-only",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter){\n        if(inputs.read_filter.indexOf(\"ReadStrandFilter\") != -1){\n            return self\n        }\n    }\n}"
                    },
                    "label": "Keep reverse strand only",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Valid only if \"SampleReadFilter\" is specified:\nThe name of the sample(s) to keep, filtering out all others  This argument must be specified at least once.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/sample",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if(self && inputs.read_filter && inputs.read_filter.indexOf(\"SampleReadFilter\") != -1){\n            return \"--sample \" + self.join(' --sample ')\n    } else {\n        return null\n    }\n}\n\n"
                    },
                    "label": "Sample",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Conditional Arguments for read-filter option"
                },
                {
                    "default": "vcf",
                    "doc": "Output VCF extension.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_extension",
                    "label": "Output VCF extension",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_extension/output_extension",
                            "symbols": [
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_extension/output_extension/vcf",
                                "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/output_extension/output_extension/vcf.gz"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Required Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "vcf"
                }
            ],
            "label": "GATK HaplotypeCaller",
            "outputs": [
                {
                    "doc": "A raw, unfiltered, highly specific callset in VCF format.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/out_variants",
                    "label": "VCF output",
                    "outputBinding": {
                        "glob": "${ \n    if (inputs.output_extension == \"vcf\")\n    {\n        return \"*.vcf\";\n    }\n    else if (inputs.output_extension == \"vcf.gz\")\n    {\n        return \"*.vcf.gz\";\n    }\n    else\n    {\n        return ''\n    }\n}",
                        "outputEval": "$(inheritMetadata(self, inputs.in_alignments))"
                    },
                    "secondaryFiles": [
                        "${ \n    if(inputs.output_extension == 'vcf'){\n        return self.basename + \".idx\";\n    } \n    else if (inputs.output_extension == 'vcf.gz'){\n        return self.basename + \".tbi\";\n    } else {\n        return null;\n    }\n}"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comfileTypes": "VCF"
                },
                {
                    "doc": "Assembled haplotypes.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/out_alignments",
                    "label": "BAM output",
                    "outputBinding": {
                        "glob": "${\n    if(inputs.bam_output){\n        return inputs.bam_output\n    } else {\n        return null\n    }\n}",
                        "outputEval": "$(inheritMetadata(self, inputs.in_alignments))"
                    },
                    "secondaryFiles": [
                        "${ \n    return self.nameroot + \".bai\";\n}"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comfileTypes": "BAM"
                },
                {
                    "doc": "Assembly graph information.",
                    "id": "#gatk_haplotypecaller_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7/out_graph",
                    "label": "Graph output",
                    "outputBinding": {
                        "glob": "${\n    if(inputs.graph_output){\n        return inputs.graph_output\n    } else {\n        return null\n    }\n}",
                        "outputEval": "$(inheritMetadata(self, inputs.in_alignments))"
                    },
                    "type": [
                        "null",
                        "File"
                    ]
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": "${\n    if(inputs.cpu_per_job){\n        return inputs.cpu_per_job;\n    } else {\n        return 1;\n    }\n}",
                    "ramMin": "${\n  var memory = 6500;\n  \n  if(inputs.mem_per_job){\n  \t memory = inputs.mem_per_job\n  }\n  if(inputs.mem_overhead_per_job){\n\treturn memory + inputs.mem_overhead_per_job; \n  }\n  else{\n  \treturn memory;\n  }\n}"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "images.sbgenomics.com/stefan_stojanovic/gatk:4.1.0.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": []
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var updateMetadata = function(file, key, value) {\n    file['metadata'][key] = value;\n    return file;\n};\n\n\nvar setMetadata = function(file, metadata) {\n    if (!('metadata' in file))\n        file['metadata'] = metadata;\n    else {\n        for (var key in metadata) {\n            file['metadata'][key] = metadata[key];\n        }\n    }\n    return file\n};\n\nvar inheritMetadata = function(o1, o2) {\n    var commonMetadata = {};\n    if (!Array.isArray(o2)) {\n        o2 = [o2]\n    }\n    for (var i = 0; i < o2.length; i++) {\n        var example = o2[i]['metadata'];\n        for (var key in example) {\n            if (i == 0)\n                commonMetadata[key] = example[key];\n            else {\n                if (!(commonMetadata[key] == example[key])) {\n                    delete commonMetadata[key]\n                }\n            }\n        }\n    }\n    if (!Array.isArray(o1)) {\n        o1 = setMetadata(o1, commonMetadata)\n    } else {\n        for (var i = 0; i < o1.length; i++) {\n            o1[i] = setMetadata(o1[i], commonMetadata)\n        }\n    }\n    return o1;\n};\n\nvar toArray = function(file) {\n    return [].concat(file);\n};\n\nvar groupBy = function(files, key) {\n    var groupedFiles = [];\n    var tempDict = {};\n    for (var i = 0; i < files.length; i++) {\n        var value = files[i]['metadata'][key];\n        if (value in tempDict)\n            tempDict[value].push(files[i]);\n        else tempDict[value] = [files[i]];\n    }\n    for (var key in tempDict) {\n        groupedFiles.push(tempDict[key]);\n    }\n    return groupedFiles;\n};\n\nvar orderBy = function(files, key, order) {\n    var compareFunction = function(a, b) {\n        if (a['metadata'][key].constructor === Number) {\n            return a['metadata'][key] - b['metadata'][key];\n        } else {\n            var nameA = a['metadata'][key].toUpperCase();\n            var nameB = b['metadata'][key].toUpperCase();\n            if (nameA < nameB) {\n                return -1;\n            }\n            if (nameA > nameB) {\n                return 1;\n            }\n            return 0;\n        }\n    };\n\n    files = files.sort(compareFunction);\n    if (order == undefined || order == \"asc\")\n        return files;\n    else\n        return files.reverse();\n};",
                        "\nvar setMetadata = function(file, metadata) {\n    if (!('metadata' in file))\n        file['metadata'] = metadata;\n    else {\n        for (var key in metadata) {\n            file['metadata'][key] = metadata[key];\n        }\n    }\n    return file\n};\n\nvar inheritMetadata = function(o1, o2) {\n    var commonMetadata = {};\n    if (!Array.isArray(o2)) {\n        o2 = [o2]\n    }\n    for (var i = 0; i < o2.length; i++) {\n        var example = o2[i]['metadata'];\n        for (var key in example) {\n            if (i == 0)\n                commonMetadata[key] = example[key];\n            else {\n                if (!(commonMetadata[key] == example[key])) {\n                    delete commonMetadata[key]\n                }\n            }\n        }\n    }\n    if (!Array.isArray(o1)) {\n        o1 = setMetadata(o1, commonMetadata)\n    } else {\n        for (var i = 0; i < o1.length; i++) {\n            o1[i] = setMetadata(o1[i], commonMetadata)\n        }\n    }\n    return o1;\n};"
                    ]
                }
            ],
            "https://sevenbridges.comappVersion": [
                "v1.0"
            ],
            "https://sevenbridges.comcategories": [
                "Genomics",
                "Variant Calling"
            ],
            "https://sevenbridges.comcontent_hash": "aad5a3e87aca93b604708277a3ea29a56b099eb4bb91277df56f7585612fb1a54",
            "https://sevenbridges.comcontributors": [
                "uros_sipetic",
                "veliborka_josipovic",
                "nemanja.vucic"
            ],
            "https://sevenbridges.comcopyOf": "veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/19",
            "https://sevenbridges.comcreatedBy": "uros_sipetic",
            "https://sevenbridges.comcreatedOn": 1553086627,
            "https://sevenbridges.comid": "uros_sipetic/gatk-4-1-0-0-demo/gatk-haplotypecaller-4-1-0-0/7",
            "https://sevenbridges.comimage_url": null,
            "https://sevenbridges.comlatestRevision": 7,
            "https://sevenbridges.comlicense": "Open source BSD (3-clause) license",
            "https://sevenbridges.comlinks": [
                {
                    "id": "#index.php",
                    "label": "Homepage"
                },
                {
                    "id": "#gatk",
                    "label": "Source Code"
                },
                {
                    "id": "#gatk-4.0.12.0.zip",
                    "label": "Download"
                },
                {
                    "id": "#201178v3",
                    "label": "Publication"
                },
                {
                    "id": "#org_broadinstitute_hellbender_tools_walkers_haplotypecaller_HaplotypeCaller.php",
                    "label": "Documentation"
                }
            ],
            "https://sevenbridges.commodifiedBy": "nemanja.vucic",
            "https://sevenbridges.commodifiedOn": 1559750439,
            "https://sevenbridges.comproject": "uros_sipetic/gatk-4-1-0-0-demo",
            "https://sevenbridges.comprojectName": "GATK 4.1.0.0 - Demo",
            "https://sevenbridges.compublisher": "sbg",
            "https://sevenbridges.comrevision": 7,
            "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/19",
            "https://sevenbridges.comrevisionsInfo": [
                {
                    "https://sevenbridges.commodifiedBy": "uros_sipetic",
                    "https://sevenbridges.commodifiedOn": 1553086627,
                    "https://sevenbridges.comrevision": 0,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/4"
                },
                {
                    "https://sevenbridges.commodifiedBy": "uros_sipetic",
                    "https://sevenbridges.commodifiedOn": 1553105347,
                    "https://sevenbridges.comrevision": 1,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/8"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1554720901,
                    "https://sevenbridges.comrevision": 2,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/13"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1554730721,
                    "https://sevenbridges.comrevision": 3,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/14"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1554999234,
                    "https://sevenbridges.comrevision": 4,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/15"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nemanja.vucic",
                    "https://sevenbridges.commodifiedOn": 1559736399,
                    "https://sevenbridges.comrevision": 5,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/17"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1559746054,
                    "https://sevenbridges.comrevision": 6,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/18"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nemanja.vucic",
                    "https://sevenbridges.commodifiedOn": 1559750439,
                    "https://sevenbridges.comrevision": 7,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-haplotypecaller-4-1-0-0/19"
                }
            ],
            "https://sevenbridges.comsbgMaintained": false,
            "https://sevenbridges.comtoolAuthor": "Broad Institute",
            "https://sevenbridges.comtoolkit": "GATK",
            "https://sevenbridges.comtoolkitVersion": "4.1.0.0",
            "https://sevenbridges.comvalidationErrors": []
        },
        {
            "arguments": [
                {
                    "position": 0,
                    "prefix": "",
                    "shellQuote": false,
                    "valueFrom": "/opt/gatk"
                },
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--java-options"
                },
                {
                    "position": 2,
                    "prefix": "",
                    "shellQuote": false,
                    "valueFrom": "${\n    if (inputs.memory_per_job) {\n        return '\\\"-Xmx'.concat(inputs.memory_per_job, 'M') + '\\\"';\n    }\n    return '\\\"-Xms1g\\\"';\n}"
                },
                {
                    "position": 3,
                    "shellQuote": false,
                    "valueFrom": "IntervalListTools"
                },
                {
                    "position": 4,
                    "prefix": "",
                    "shellQuote": false,
                    "valueFrom": "${\n    var scatter_count = inputs.scatter_count ? inputs.scatter_count : 1;\n    if (scatter_count > 1)\n    {\n        return \"--OUTPUT out\";\n    }\n    else\n    {\n        return \"--OUTPUT test.interval_list\";\n    }\n    \n}"
                },
                {
                    "position": -1,
                    "prefix": "",
                    "shellQuote": false,
                    "valueFrom": "${\n    return \"mkdir out && \";\n}"
                },
                {
                    "position": 99,
                    "prefix": "&& python",
                    "shellQuote": false,
                    "valueFrom": "rename_intervals.py"
                }
            ],
            "baseCommand": [],
            "class": "CommandLineTool",
            "doc": "This tool offers multiple interval list file manipulation capabilities including sorting, merging, subtracting, padding, and other set-theoretic operations. \n\nThe default action is to merge and sort genomic intervals provided as the input. Compatible input files are INTERVAL_LIST and VCF files. **IntervalListTools** can also \"scatter\" the output into many interval files. This can be useful for creating multiple interval lists for scattering an analysis execution.\n\n###Common Use Cases\n\n- Combine the intervals from two interval lists:\n```\njava -jar picard.jar IntervalListTools \\\n      ACTION=CONCAT \\\n      I=input.interval_list \\\n      I=input_2.interval_list \\\n      O=new.interval_list\n```\n- Combine the intervals from two interval lists, sorting and merging overlapping and abutting intervals:\n```\n java -jar picard.jar IntervalListTools \\\n       ACTION=CONCAT \\\n       SORT=true \\\n       UNIQUE=true \\\n       I=input.interval_list \\\n       I=input_2.interval_list \\\n       O=new.interval_list \n```\n- Subtract the intervals in **second_input** (`SECOND_INPUT`) from those in **in_intervals** (`INPUT`):\n```\n java -jar picard.jar IntervalListTools \\\n       ACTION=SUBTRACT \\\n       I=input.interval_list \\\n       SI=input_2.interval_list \\\n       O=new.interval_list \n```\n- Find bases that are in either *input1.interval_list* or *input2.interval_list*, and also in *input3.interval_list*:\n```\n java -jar picard.jar IntervalListTools \\\n       ACTION=INTERSECT \\\n       I=input1.interval_list \\\n       I=input2.interval_list \\\n       SI=input3.interval_list \\\n       O=new.interval_list \n```\n- Split intervals list file using * scatter_count* (`SCATTER_COUNT`) option:\n```\n java -jar picard.jar IntervalListTools \\\n       I=input.interval_list \\\n       SCATTER_COUNT=2 \n```\n\n\n###Common Issues and Important Notes\n\n- A SAM style header must be present at the top of the *interval_list* file. After the header, the file then contains records, one per line in text format with the following tab-separated values. Example of the *interval_list* file: \n```\n@HD    VN:1.0\n@SQ    SN:chr1    LN:501\n@SQ    SN:chr2    LN:401\nchr1    1    100    +    starts at the first base of the contig and covers 100 bases\nchr2    100    100    +    interval with exactly one base\n```\n- The coordinate system is 1-based, closed-ended so that the first base in a sequence has position 1, and both the start and the end positions are included in an interval.\n-  The **Interval list** input file should be denoted with the extension INTERVAL_LIST.\n\n\n###Changes Introduced by Seven Bridges\n\nIf no additional parameter is set, the app will output the INTERVAL_LIST file given on the input.\n\n\n###Performance Benchmarking\nThe execution time takes several minutes on the default instance. Unless specified otherwise, the default AWS instance used to run the **IntervalListTools** will be c4.2xlarge (8CPUs and 16GB RAM).",
            "id": "#gatk_intervallisttools_4_1_0_0.cwl",
            "inputs": [
                {
                    "doc": "Action to take on inputs. Possible values: { CONCAT (the concatenation of all the intervals in all the inputs, no sorting or merging of overlapping/abutting intervals implied. Will result in a possibly unsorted list unless requested otherwise.) UNION (like concatenate but with UNIQUE and SORT implied, the result being the set-wise union of all inputs, with overlapping and abutting intervals merged into one.) INTERSECT (the sorted and merged set of all loci that are contained in all of the inputs.) SUBTRACT (subtracts the intervals in second_input from those in input. The resulting loci are those in input that are not in second_input.) symdiff (results in loci that are in input or second_input but are not in both.) overlaps (outputs the entire intervals from input that have bases which overlap any interval from second_input. Note that this is different than intersect in that each original interval is either emitted in its entirety, or not at all.) }.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/action",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--ACTION",
                        "shellQuote": false
                    },
                    "label": "Action",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/action/action",
                            "symbols": [
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/action/action/CONCAT",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/action/action/UNION",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/action/action/INTERSECT",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/action/action/SUBTRACT",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/action/action/SYMDIFF",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/action/action/OVERLAPS"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "CONCAT"
                },
                {
                    "doc": "If set to a positive value will create a new interval list with the original intervals broken up at integer multiples of this value. Set to 0 to not break up intervals.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/break_bands_at_multiples_of",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--BREAK_BANDS_AT_MULTIPLES_OF",
                        "shellQuote": false
                    },
                    "label": "Break bands at multiples of",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comaltPrefix": "-BRK",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0"
                },
                {
                    "doc": "One or more lines of comment to add to the header of the output file (as @CO lines in the SAM header).  This argument may be specified 0 or more times.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/comment",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self)\n    {\n        var cmd = [];\n        for (var i = 0; i < self.length; i++) \n        {\n            cmd.push('--COMMENT', self[i]);\n        }\n        return cmd.join(' ');\n    }\n    \n}"
                    },
                    "label": "Comment",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "Compression level for all compressed files created (e.g. BAM and VCF).",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/compression_level",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--COMPRESSION_LEVEL",
                        "shellQuote": false
                    },
                    "label": "Compression level",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "2"
                },
                {
                    "doc": "Number of CPUs to be used per job.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/cpu_per_job",
                    "label": "CPU per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform options",
                    "https://sevenbridges.comtoolDefaultValue": "1"
                },
                {
                    "doc": "Whether to include filtered variants in the VCF when generating an interval list from VCF.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/include_filtered",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--INCLUDE_FILTERED",
                        "shellQuote": false
                    },
                    "label": "Include filtered",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "One or more interval lists. If multiple interval lists are provided the output is the result of merging the inputs. Supported formats are interval_list and VCF. This argument must be specified at least once.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/in_intervals",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "",
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self)\n    {\n        var cmd = [];\n        for (var i = 0; i < self.length; i++) \n        {\n            cmd.push('--INPUT', self[i].path);\n        }\n        return cmd.join(' ');\n    }\n    \n}"
                    },
                    "label": "Interval list",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "https://sevenbridges.comaltPrefix": "-I",
                    "https://sevenbridges.comcategory": "Required Arguments",
                    "https://sevenbridges.comfileTypes": "VCF, INTERVAL_LIST"
                },
                {
                    "doc": "Produce the inverse list of intervals, that is, the regions in the genome that are not covered by any of the input intervals. Will merge abutting intervals first. Output will be sorted.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/invert",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--INVERT",
                        "shellQuote": false
                    },
                    "label": "Invert",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "When writing files that need to be sorted, this will specify the number of records stored in RAM before spilling to disk. Increasing this number reduces the number of file handles needed to sort the file, and increases the amount of RAM needed.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/max_records_in_ram",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--MAX_RECORDS_IN_RAM",
                        "shellQuote": false
                    },
                    "label": "Max records in ram",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "500000"
                },
                {
                    "doc": "This input allows a user to set the desired overhead memory when running a tool or adding it to a workflow. This amount will be added to the Memory per job in the Memory requirements section but it will not be added to the -Xmx parameter leaving some memory not occupied which can be used as stack memory (-Xmx parameter defines heap memory). This input should be defined in MB (for both the platform part and the -Xmx part if Java tool is wrapped).",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/memory_overhead_per_job",
                    "label": "Memory overhead per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform Options",
                    "https://sevenbridges.comtoolDefaultValue": "7"
                },
                {
                    "doc": "This input allows a user to set the desired memory requirement when running a tool or adding it to a workflow. This value should be propagated to the -Xmx parameter too.This input should be defined in MB (for both the platform part and the -Xmx part if Java tool is wrapped).",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/memory_per_job",
                    "label": "Memory per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform options",
                    "https://sevenbridges.comtoolDefaultValue": "2048"
                },
                {
                    "doc": "What value (if anything) to output to stdout (for scripting).",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/output_value",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--OUTPUT_VALUE",
                        "shellQuote": false
                    },
                    "label": "Output value",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/output_value/output_value",
                            "symbols": [
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/output_value/output_value/NONE",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/output_value/output_value/BASES",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/output_value/output_value/INTERVALS"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "NONE"
                },
                {
                    "doc": "The amount to pad each end of the intervals by before other operations are undertaken. Negative numbers are allowed and indicate intervals should be shrunk. Resulting intervals < 0 bases long will be removed. Padding is applied to the interval lists (both INPUT and SECOND_INPUT, if provided) before the ACTION is performed.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/padding",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--PADDING",
                        "shellQuote": false
                    },
                    "label": "Padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "0"
                },
                {
                    "doc": "Reference sequence file.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/in_reference",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--REFERENCE_SEQUENCE",
                        "shellQuote": false
                    },
                    "label": "Reference sequence",
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comaltPrefix": "-R",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "FASTA, FA",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "When scattering with this argument, each of the resultant files will (ideally) have this amount of 'content', which means either base-counts or interval-counts depending on SUBDIVISION_MODE. When provided, overrides SCATTER_COUNT.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/scatter_content",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--SCATTER_CONTENT",
                        "shellQuote": false
                    },
                    "label": "Scatter content",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "The number of files into which to scatter the resulting list by locus; in some situations, fewer intervals may be emitted.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/scatter_count",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--SCATTER_COUNT",
                        "shellQuote": false
                    },
                    "label": "Scatter count",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "1"
                },
                {
                    "doc": "Second set of intervals for SUBTRACT and DIFFERENCE operations. This argument may be specified 0 or more times.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/second_input",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--SECOND_INPUT",
                        "shellQuote": false
                    },
                    "label": "Second input",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-SI",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "VCF, INTERVAL_LIST",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "If true, sort the resulting interval list by coordinate.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/sort",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--SORT",
                        "shellQuote": false
                    },
                    "label": "Sort",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "true"
                },
                {
                    "doc": "The mode used to scatter the interval list. Possible values: { INTERVAL_SUBDIVISION (scatter the interval list into similarly sized interval lists (by base count), breaking up intervals as needed.) BALANCING_WITHOUT_INTERVAL_SUBDIVISION (scatter the interval list into similarly sized interval lists (by base count), but without breaking up intervals.) BALANCING_WITHOUT_INTERVAL_SUBDIVISION_WITH_OVERFLOW (scatter the interval list into similarly sized interval lists (by base count), but without breaking up intervals. Will overflow current interval list so that the remaining lists will not have too many bases to deal with.) interval_count (scatter the interval list into similarly sized interval lists (by interval count, not by base count). Resulting interval lists will contain similar number of intervals.) }.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/subdivision_mode",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--SUBDIVISION_MODE",
                        "shellQuote": false
                    },
                    "label": "Subdivision mode",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/subdivision_mode/subdivision_mode",
                            "symbols": [
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/subdivision_mode/subdivision_mode/INTERVAL_SUBDIVISION",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/subdivision_mode/subdivision_mode/BALANCING_WITHOUT_INTERVAL_SUBDIVISION",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/subdivision_mode/subdivision_mode/BALANCING_WITHOUT_INTERVAL_SUBDIVISION_WITH_OVERFLOW",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/subdivision_mode/subdivision_mode/INTERVAL_COUNT"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comaltPrefix": "-M",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "INTERVAL_SUBDIVISION"
                },
                {
                    "doc": "If true, merge overlapping and adjacent intervals to create a list of unique intervals. Implies SORT=true.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/unique",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--UNIQUE",
                        "shellQuote": false
                    },
                    "label": "Unique",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "false"
                },
                {
                    "doc": "Validation stringency for all SAM files read by this program. Setting stringency to silent can improve performance when processing a bam file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/validation_stringency",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--VALIDATION_STRINGENCY",
                        "shellQuote": false
                    },
                    "label": "Validation stringency",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/validation_stringency/validation_stringency",
                            "symbols": [
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/validation_stringency/validation_stringency/STRICT",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/validation_stringency/validation_stringency/LENIENT",
                                "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/validation_stringency/validation_stringency/SILENT"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "STRICT"
                }
            ],
            "label": "GATK IntervalListTools",
            "outputs": [
                {
                    "doc": "Output list of intervals, processed per the tool's specifications (union, intersection, split list... ).",
                    "id": "#gatk_intervallisttools_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4/output_interval_list",
                    "label": "Output interval list",
                    "outputBinding": {
                        "glob": "${\n    var scatter_count = inputs.scatter_count ? inputs.scatter_count : 1;\n    if (scatter_count > 1)\n    {\n        return \"out/*/*.interval_list\";\n    }\n    else\n    {\n        return \"test.interval_list\";\n    }\n}",
                        "outputEval": "$(inheritMetadata(self, inputs.in_intervals))"
                    },
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "https://sevenbridges.comfileTypes": "INTERVAL_LIST"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": "${\n    return inputs.cpu_per_job ? inputs.cpu_per_job : 1\n}",
                    "ramMin": "${\n    var memory = 2048;\n    if (inputs.memory_per_job) \n    {\n        memory = inputs.memory_per_job;\n    }\n    if (inputs.memory_overhead_per_job)\n    {\n        memory += inputs.memory_overhead_per_job;\n    }\n    return memory;\n}"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "images.sbgenomics.com/stefan_stojanovic/gatk:4.1.0.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "import glob, os\n# Works around a JES limitation where multiples files with the same name overwrite each other when globbed\nintervals = sorted(glob.glob(\"out/*/*.interval_list\"))\nfor i, interval in enumerate(intervals):\n    (directory, filename) = os.path.split(interval)\n    newName = os.path.join(directory, str(i + 1) + filename)\n    os.rename(interval, newName)\nprint(len(intervals))",
                            "entryname": "rename_intervals.py",
                            "writable": false
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var updateMetadata = function(file, key, value) {\n    file['metadata'][key] = value;\n    return file;\n};\n\n\nvar setMetadata = function(file, metadata) {\n    if (!('metadata' in file))\n        file['metadata'] = metadata;\n    else {\n        for (var key in metadata) {\n            file['metadata'][key] = metadata[key];\n        }\n    }\n    return file\n};\n\nvar inheritMetadata = function(o1, o2) {\n    var commonMetadata = {};\n    if (!Array.isArray(o2)) {\n        o2 = [o2]\n    }\n    for (var i = 0; i < o2.length; i++) {\n        var example = o2[i]['metadata'];\n        for (var key in example) {\n            if (i == 0)\n                commonMetadata[key] = example[key];\n            else {\n                if (!(commonMetadata[key] == example[key])) {\n                    delete commonMetadata[key]\n                }\n            }\n        }\n    }\n    if (!Array.isArray(o1)) {\n        o1 = setMetadata(o1, commonMetadata)\n    } else {\n        for (var i = 0; i < o1.length; i++) {\n            o1[i] = setMetadata(o1[i], commonMetadata)\n        }\n    }\n    return o1;\n};\n\nvar toArray = function(file) {\n    return [].concat(file);\n};\n\nvar groupBy = function(files, key) {\n    var groupedFiles = [];\n    var tempDict = {};\n    for (var i = 0; i < files.length; i++) {\n        var value = files[i]['metadata'][key];\n        if (value in tempDict)\n            tempDict[value].push(files[i]);\n        else tempDict[value] = [files[i]];\n    }\n    for (var key in tempDict) {\n        groupedFiles.push(tempDict[key]);\n    }\n    return groupedFiles;\n};\n\nvar orderBy = function(files, key, order) {\n    var compareFunction = function(a, b) {\n        if (a['metadata'][key].constructor === Number) {\n            return a['metadata'][key] - b['metadata'][key];\n        } else {\n            var nameA = a['metadata'][key].toUpperCase();\n            var nameB = b['metadata'][key].toUpperCase();\n            if (nameA < nameB) {\n                return -1;\n            }\n            if (nameA > nameB) {\n                return 1;\n            }\n            return 0;\n        }\n    };\n\n    files = files.sort(compareFunction);\n    if (order == undefined || order == \"asc\")\n        return files;\n    else\n        return files.reverse();\n};",
                        "\nvar setMetadata = function(file, metadata) {\n    if (!('metadata' in file))\n        file['metadata'] = metadata;\n    else {\n        for (var key in metadata) {\n            file['metadata'][key] = metadata[key];\n        }\n    }\n    return file\n};\n\nvar inheritMetadata = function(o1, o2) {\n    var commonMetadata = {};\n    if (!Array.isArray(o2)) {\n        o2 = [o2]\n    }\n    for (var i = 0; i < o2.length; i++) {\n        var example = o2[i]['metadata'];\n        for (var key in example) {\n            if (i == 0)\n                commonMetadata[key] = example[key];\n            else {\n                if (!(commonMetadata[key] == example[key])) {\n                    delete commonMetadata[key]\n                }\n            }\n        }\n    }\n    if (!Array.isArray(o1)) {\n        o1 = setMetadata(o1, commonMetadata)\n    } else {\n        for (var i = 0; i < o1.length; i++) {\n            o1[i] = setMetadata(o1[i], commonMetadata)\n        }\n    }\n    return o1;\n};"
                    ]
                }
            ],
            "https://sevenbridges.comappVersion": [
                "v1.0"
            ],
            "https://sevenbridges.comcategories": [
                "Utilities",
                "BED Processing"
            ],
            "https://sevenbridges.comcontent_hash": "ad8098a8ef53e9c95647c2c4b16fb6e2616f49f3b2589d1241f7c1a034153332b",
            "https://sevenbridges.comcontributors": [
                "uros_sipetic",
                "veliborka_josipovic"
            ],
            "https://sevenbridges.comcopyOf": "veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-intervallisttools-4-1-0-0/19",
            "https://sevenbridges.comcreatedBy": "uros_sipetic",
            "https://sevenbridges.comcreatedOn": 1553015434,
            "https://sevenbridges.comid": "uros_sipetic/gatk-4-1-0-0-demo/gatk-intervallisttools-4-1-0-0/4",
            "https://sevenbridges.comimage_url": null,
            "https://sevenbridges.comlatestRevision": 4,
            "https://sevenbridges.comlicense": "Open source BSD (3-clause) license",
            "https://sevenbridges.comlinks": [
                {
                    "id": "#picard_util_IntervalListTools.php",
                    "label": "Homepage"
                }
            ],
            "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
            "https://sevenbridges.commodifiedOn": 1559740786,
            "https://sevenbridges.comproject": "uros_sipetic/gatk-4-1-0-0-demo",
            "https://sevenbridges.comprojectName": "GATK 4.1.0.0 - Demo",
            "https://sevenbridges.compublisher": "sbg",
            "https://sevenbridges.comrevision": 4,
            "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-intervallisttools-4-1-0-0/19",
            "https://sevenbridges.comrevisionsInfo": [
                {
                    "https://sevenbridges.commodifiedBy": "uros_sipetic",
                    "https://sevenbridges.commodifiedOn": 1553015434,
                    "https://sevenbridges.comrevision": 0,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-intervallisttools-4-1-0-0/14"
                },
                {
                    "https://sevenbridges.commodifiedBy": "uros_sipetic",
                    "https://sevenbridges.commodifiedOn": 1553023178,
                    "https://sevenbridges.comrevision": 1,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-intervallisttools-4-1-0-0/16"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1554720910,
                    "https://sevenbridges.comrevision": 2,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-intervallisttools-4-1-0-0/17"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1554999245,
                    "https://sevenbridges.comrevision": 3,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-intervallisttools-4-1-0-0/18"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1559740786,
                    "https://sevenbridges.comrevision": 4,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-intervallisttools-4-1-0-0/19"
                }
            ],
            "https://sevenbridges.comsbgMaintained": false,
            "https://sevenbridges.comtoolAuthor": "Broad Institute",
            "https://sevenbridges.comtoolkit": "GATK",
            "https://sevenbridges.comtoolkitVersion": "4.1.0.0",
            "https://sevenbridges.comvalidationErrors": [],
            "https://sevenbridges.comwrapperAuthor": "nemanja.vucic, veliborka_josipovic"
        },
        {
            "arguments": [
                {
                    "position": 0,
                    "prefix": "",
                    "shellQuote": false,
                    "valueFrom": "/opt/gatk"
                },
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--java-options"
                },
                {
                    "position": 2,
                    "prefix": "",
                    "shellQuote": false,
                    "valueFrom": "${\n    if (inputs.memory_per_job) {\n        return '\\\"-Xmx'.concat(inputs.memory_per_job, 'M') + '\\\"';\n    }\n    return '\\\"-Xms2000m\\\"';\n}"
                },
                {
                    "position": 3,
                    "shellQuote": false,
                    "valueFrom": "MergeVcfs"
                },
                {
                    "position": 4,
                    "prefix": "",
                    "shellQuote": false,
                    "valueFrom": "${\n    var in_variants = [].concat(inputs.in_variants);\n    var output_prefix = \"\";\n    \n    var vcf_count = 0;\n    var vcf_gz_count = 0;\n    var bcf_count = 0;\n    var gvcf_count = 0;\n    var gvcf_gz_count = 0;\n    \n    for (var i = 0; i < in_variants.length; i++)\n    {\n        if (in_variants[i].path.endsWith('vcf') && !(in_variants[i].path.endsWith('g.vcf')) )\n            vcf_count += 1\n        else if (in_variants[i].path.endsWith('vcf.gz') && !(in_variants[i].path.endsWith('g.vcf.gz')))\n            vcf_gz_count += 1\n        else if (in_variants[i].path.endsWith('bcf'))\n            bcf_count += 1\n        else if (in_variants[i].path.endsWith('g.vcf'))\n            gvcf_count += 1\n        else if (in_variants[i].path.endsWith('g.vcf.gz'))\n            gvcf_gz_count += 1\n        \n    }\n    \n    var max_ext = Math.max(vcf_count, vcf_gz_count, bcf_count, gvcf_count, gvcf_gz_count)\n    var most_frequent_ext = (max_ext == vcf_count) ? \"vcf\" : (max_ext == vcf_gz_count) ? \"vcf.gz\" : (max_ext == bcf_count) ? \"bcf\" : (max_ext == gvcf_count) ? \"g.vcf\" : \"g.vcf.gz\";\n    var out_format = inputs.output_file_format;\n    var out_ext = \"\";\n    if (out_format)\n    {\n        out_ext = ((most_frequent_ext == \"g.vcf\" || most_frequent_ext == \"g.vcf.gz\") && (out_format == \"vcf\" || out_format == \"vcf.gz\")) ? \"g.\" + out_format : ((most_frequent_ext == \"g.vcf\" || most_frequent_ext == \"g.vcf.gz\") && (out_format == \"bcf\" )) ? most_frequent_ext : out_format;\n    }\n    else\n    {\n        out_ext = most_frequent_ext;\n    }\n    \n    if (inputs.output_prefix)\n    {\n        output_prefix = inputs.output_prefix;\n    }\n    else\n    {\n        if (in_variants.length > 1)\n        {\n            in_variants.sort(function(file1, file2) {\n                var file1_name = file1.basename.toUpperCase();\n                var file2_name = file2.basename.toUpperCase();\n                if (file1_name < file2_name) {\n                    return -1;\n                }\n                if (file1_name > file2_name) {\n                    return 1;\n                }\n                // names must be equal\n                return 0;\n            });\n        }\n        \n        var in_variants_first =  in_variants[0];\n        if (in_variants_first.metadata && in_variants_first.metadata.sample_id)\n        {\n            output_prefix = in_variants_first.metadata.sample_id;\n\n        }\n        else\n        {\n            output_prefix = in_variants_first.basename.split('.')[0];\n        }\n        \n        if (in_variants.length > 1)\n        {\n            output_prefix = output_prefix + \".\" + in_variants.length;\n        }\n    }\n    \n    return \"--OUTPUT \" + output_prefix + \".merged.\" + out_ext;\n}"
                }
            ],
            "baseCommand": [],
            "class": "CommandLineTool",
            "doc": "The **GATK MergeVcfs** tool combines multiple variant files into a single variant file. \n\n*A list of **all inputs and parameters** with corresponding descriptions can be found at the bottom of the page.*\n\n###Common Use Cases\n\n* The **MergeVcfs** tool requires one or more input files in VCF format on its **Input variant files** (`--INPUT`) input. The input files can be in VCF format (can be gzipped, i.e. ending in \".vcf.gz\", or binary compressed, i.e. ending in \".bcf\"). The tool generates a VCF file on its **Output merged VCF or BCF file** output.\n\n* The **MergeVcfs** tool supports a sequence dictionary file (typically name ending in .dict) on its **Sequence dictionary** (`--SEQUENCE_DICTIONARY`) input if the input VCF does not contain a complete contig list and if the output index is to be created (true by default).\n\n* The output file is sorted (i) according to the dictionary and (ii) by coordinate.\n\n* Usage example:\n\n```\ngatk MergeVcfs \\\n          --INPUT input_variants.01.vcf \\\n          --INPUT input_variants.02.vcf.gz \\\n          --OUTPUT output_variants.vcf.gz\n```\n\n###Changes Introduced by Seven Bridges\n\n* The output file will be prefixed using the **Output prefix** parameter. In case **Output prefix** is not provided, the input files provided on the **Input variant files** input will be alphabetically sorted by name and  output prefix will be equal to the Sample ID metadata from the first element from that list, if the Sample ID metadata exists. Otherwise, output prefix will be inferred from the filename of the first element from this list. Moreover, the number of input files will be added after the output prefix as well as the tool specific extension which is **merged**. This way, having identical names of the output files between runs is avoided.\n\n* The user has a possibility to specify the output file format using the **Output file format** argument. The default output format is \"vcf.gz\".\n\n###Common Issues and Important Notes\n\n* Note 1: If running this tool on multi-sample input files (originating from e.g. some scatter-gather runs), the input files must contain the same sample names in the same column order. \n\n* Note 2: Input file headers must contain compatible declarations for common annotations (INFO, FORMAT fields) and filters.\n\n* Note 3: Input files variant records must be sorted by their contig and position following the sequence dictionary provided or the header contig list.\n\n###Performance Benchmarking\n\nThis tool is ultra fast, with a running time less than a minute on the default AWS c4.2xlarge instance.\n\n###References\n\n[1] [GATK MergeVcfs](https://software.broadinstitute.org/gatk/documentation/tooldocs/4.1.0.0/picard_vcf_MergeVcfs.php)",
            "id": "#gatk_mergevcfs_4_1_0_0.cwl",
            "inputs": [
                {
                    "doc": "VCF or BCF input files (file format is determined by file extension).",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/in_variants",
                    "inputBinding": {
                        "position": 4,
                        "shellQuote": false,
                        "valueFrom": "${\n    if (self)\n    {\n        var cmd = [];\n        for (var i = 0; i < self.length; i++) \n        {\n            cmd.push('--INPUT', self[i].path);\n            \n        }\n        return cmd.join(' ');\n    }\n}"
                    },
                    "label": "Input variants file",
                    "secondaryFiles": [
                        "${\n    if (self.nameext == \".vcf\")\n    {\n        return self.basename + \".idx\";\n    }\n    else\n    {\n        return self.basename + \".tbi\";\n    }\n}"
                    ],
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "https://sevenbridges.comaltPrefix": "-I",
                    "https://sevenbridges.comcategory": "Required Arguments",
                    "https://sevenbridges.comfileTypes": "VCF, VCF.GZ, BCF"
                },
                {
                    "doc": "Compression level for all compressed files created (e.g. BAM and VCF).",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/compression_level",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--COMPRESSION_LEVEL",
                        "shellQuote": false
                    },
                    "label": "Compression level",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "2"
                },
                {
                    "doc": "When writing files that need to be sorted, this will specify the number of records stored in RAM before spilling to disk. Increasing this number reduces the number of file handles needed to sort the file, and increases the amount of RAM needed.",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/max_records_in_ram",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--MAX_RECORDS_IN_RAM",
                        "shellQuote": false
                    },
                    "label": "Max records in RAM",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comtoolDefaultValue": "500000"
                },
                {
                    "doc": "This input allows a user to set the desired overhead memory when running a tool or adding it to a workflow. This amount will be added to the Memory per job in the Memory requirements section but it will not be added to the -Xmx parameter leaving some memory not occupied which can be used as stack memory (-Xmx parameter defines heap memory). This input should be defined in MB (for both the platform part and the -Xmx part if Java tool is wrapped).",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/memory_overhead_per_job",
                    "label": "Memory overhead per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform Options"
                },
                {
                    "doc": "This input allows a user to set the desired memory requirement when running a tool or adding it to a workflow. This value should be propagated to the -Xmx parameter too.This input should be defined in MB (for both the platform part and the -Xmx part if Java tool is wrapped).",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/memory_per_job",
                    "label": "Memory per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform Options",
                    "https://sevenbridges.comtoolDefaultValue": "2048 MB"
                },
                {
                    "doc": "The index sequence dictionary to use instead of the sequence dictionary in the input files.",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/sequence_dictionary",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--SEQUENCE_DICTIONARY",
                        "shellQuote": false
                    },
                    "label": "Sequence dictionary",
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comaltPrefix": "-D",
                    "https://sevenbridges.comcategory": "Optional Arguments",
                    "https://sevenbridges.comfileTypes": "DICT",
                    "https://sevenbridges.comtoolDefaultValue": "null"
                },
                {
                    "doc": "This input allows a user to set the desired CPU requirement when running a tool or adding it to a workflow.",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/cpu_per_job",
                    "label": "CPU per job",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://sevenbridges.comcategory": "Platform options",
                    "https://sevenbridges.comtoolDefaultValue": "1"
                },
                {
                    "doc": "Output file format.",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/output_file_format",
                    "label": "Output file format",
                    "type": [
                        "null",
                        {
                            "name": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/output_file_format/output_file_format",
                            "symbols": [
                                "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/output_file_format/output_file_format/vcf",
                                "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/output_file_format/output_file_format/bcf",
                                "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/output_file_format/output_file_format/vcf.gz"
                            ],
                            "type": "enum"
                        }
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments"
                },
                {
                    "doc": "Output file name prefix.",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/output_prefix",
                    "label": "Output prefix",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://sevenbridges.comcategory": "Optional Arguments"
                }
            ],
            "label": "GATK MergeVcfs",
            "outputs": [
                {
                    "doc": "The merged VCF or BCF file. File format is determined by file extension.",
                    "id": "#gatk_mergevcfs_4_1_0_0.cwl/uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7/out_variants",
                    "label": "Output merged VCF or BCF file",
                    "outputBinding": {
                        "glob": "${\n    var in_variants = [].concat(inputs.in_variants);\n    \n    var vcf_count = 0;\n    var vcf_gz_count = 0;\n    var bcf_count = 0;\n    var gvcf_count = 0;\n    var gvcf_gz_count = 0;\n    \n    for (var i = 0; i < in_variants.length; i++)\n    {\n        if (in_variants[i].path.endsWith('vcf') && !(in_variants[i].path.endsWith('g.vcf')) )\n            vcf_count += 1\n        else if (in_variants[i].path.endsWith('vcf.gz') && !(in_variants[i].path.endsWith('g.vcf.gz')))\n            vcf_gz_count += 1\n        else if (in_variants[i].path.endsWith('bcf'))\n            bcf_count += 1\n        else if (in_variants[i].path.endsWith('g.vcf'))\n            gvcf_count += 1\n        else if (in_variants[i].path.endsWith('g.vcf.gz'))\n            gvcf_gz_count += 1\n        \n    }\n    \n    var max_ext = Math.max(vcf_count, vcf_gz_count, bcf_count, gvcf_count, gvcf_gz_count)\n    var most_frequent_ext = (max_ext == vcf_count) ? \"vcf\" : (max_ext == vcf_gz_count) ? \"vcf.gz\" : (max_ext == bcf_count) ? \"bcf\" : (max_ext == gvcf_count) ? \"g.vcf\" : \"g.vcf.gz\";\n    var out_format = inputs.output_file_format;\n    var out_ext = \"\";\n    if (out_format)\n    {\n        out_ext = ((most_frequent_ext == \"g.vcf\" || most_frequent_ext == \"g.vcf.gz\") && (out_format == \"vcf\" || out_format == \"vcf.gz\")) ? \"g.\" + out_format : ((most_frequent_ext == \"g.vcf\" || most_frequent_ext == \"g.vcf.gz\") && (out_format == \"bcf\" )) ? most_frequent_ext : out_format;   \n    }\n    else\n    {\n        out_ext = most_frequent_ext;\n    }\n    return \"*\" + out_ext;\n    \n}",
                        "outputEval": "$(inheritMetadata(self, inputs.in_variants))"
                    },
                    "secondaryFiles": [
                        "${\n    return self.basename + \".tbi\";\n}\n"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://sevenbridges.comfileTypes": "VCF, VCF.GZ, BCF"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": "${\n    return inputs.cpu_per_job ? inputs.cpu_per_job : 1\n}",
                    "ramMin": "${\n    var memory = 3500;\n    if (inputs.memory_per_job) \n    {\n        memory = inputs.memory_per_job;\n    }\n    if (inputs.memory_overhead_per_job)\n    {\n        memory += inputs.memory_overhead_per_job;\n    }\n    return memory;\n}"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "images.sbgenomics.com/stefan_stojanovic/gatk:4.1.0.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": []
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var updateMetadata = function(file, key, value) {\n    file['metadata'][key] = value;\n    return file;\n};\n\n\nvar setMetadata = function(file, metadata) {\n    if (!('metadata' in file))\n        file['metadata'] = metadata;\n    else {\n        for (var key in metadata) {\n            file['metadata'][key] = metadata[key];\n        }\n    }\n    return file\n};\n\nvar inheritMetadata = function(o1, o2) {\n    var commonMetadata = {};\n    if (!Array.isArray(o2)) {\n        o2 = [o2]\n    }\n    for (var i = 0; i < o2.length; i++) {\n        var example = o2[i]['metadata'];\n        for (var key in example) {\n            if (i == 0)\n                commonMetadata[key] = example[key];\n            else {\n                if (!(commonMetadata[key] == example[key])) {\n                    delete commonMetadata[key]\n                }\n            }\n        }\n    }\n    if (!Array.isArray(o1)) {\n        o1 = setMetadata(o1, commonMetadata)\n    } else {\n        for (var i = 0; i < o1.length; i++) {\n            o1[i] = setMetadata(o1[i], commonMetadata)\n        }\n    }\n    return o1;\n};\n\nvar toArray = function(file) {\n    return [].concat(file);\n};\n\nvar groupBy = function(files, key) {\n    var groupedFiles = [];\n    var tempDict = {};\n    for (var i = 0; i < files.length; i++) {\n        var value = files[i]['metadata'][key];\n        if (value in tempDict)\n            tempDict[value].push(files[i]);\n        else tempDict[value] = [files[i]];\n    }\n    for (var key in tempDict) {\n        groupedFiles.push(tempDict[key]);\n    }\n    return groupedFiles;\n};\n\nvar orderBy = function(files, key, order) {\n    var compareFunction = function(a, b) {\n        if (a['metadata'][key].constructor === Number) {\n            return a['metadata'][key] - b['metadata'][key];\n        } else {\n            var nameA = a['metadata'][key].toUpperCase();\n            var nameB = b['metadata'][key].toUpperCase();\n            if (nameA < nameB) {\n                return -1;\n            }\n            if (nameA > nameB) {\n                return 1;\n            }\n            return 0;\n        }\n    };\n\n    files = files.sort(compareFunction);\n    if (order == undefined || order == \"asc\")\n        return files;\n    else\n        return files.reverse();\n};",
                        "\nvar setMetadata = function(file, metadata) {\n    if (!('metadata' in file))\n        file['metadata'] = metadata;\n    else {\n        for (var key in metadata) {\n            file['metadata'][key] = metadata[key];\n        }\n    }\n    return file\n};\n\nvar inheritMetadata = function(o1, o2) {\n    var commonMetadata = {};\n    if (!Array.isArray(o2)) {\n        o2 = [o2]\n    }\n    for (var i = 0; i < o2.length; i++) {\n        var example = o2[i]['metadata'];\n        for (var key in example) {\n            if (i == 0)\n                commonMetadata[key] = example[key];\n            else {\n                if (!(commonMetadata[key] == example[key])) {\n                    delete commonMetadata[key]\n                }\n            }\n        }\n    }\n    if (!Array.isArray(o1)) {\n        o1 = setMetadata(o1, commonMetadata)\n    } else {\n        for (var i = 0; i < o1.length; i++) {\n            o1[i] = setMetadata(o1[i], commonMetadata)\n        }\n    }\n    return o1;\n};"
                    ]
                }
            ],
            "https://sevenbridges.comappVersion": [
                "v1.0"
            ],
            "https://sevenbridges.comcategories": [
                "Utilities",
                "VCF Processing"
            ],
            "https://sevenbridges.comcontent_hash": "a3c47ffaf0fdf430a864f2f88573d1a01b163f5034538733a26e02980d05f2acd",
            "https://sevenbridges.comcontributors": [
                "nemanja.vucic",
                "veliborka_josipovic",
                "uros_sipetic",
                "nens"
            ],
            "https://sevenbridges.comcopyOf": "veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/26",
            "https://sevenbridges.comcreatedBy": "uros_sipetic",
            "https://sevenbridges.comcreatedOn": 1552929960,
            "https://sevenbridges.comid": "uros_sipetic/gatk-4-1-0-0-demo/gatk-mergevcfs-4-1-0-0/7",
            "https://sevenbridges.comimage_url": null,
            "https://sevenbridges.comlatestRevision": 7,
            "https://sevenbridges.comlicense": "Open source BSD (3-clause) license",
            "https://sevenbridges.comlinks": [
                {
                    "id": "#_2",
                    "label": "Homepage"
                },
                {
                    "id": "#",
                    "label": "Source Code"
                },
                {
                    "$import": "#gatk-4.1.0.0.zip"
                },
                {
                    "$import": "#pubmed"
                },
                {
                    "id": "#picard_vcf_MergeVcfs.php",
                    "label": "Documentation"
                }
            ],
            "https://sevenbridges.commodifiedBy": "nens",
            "https://sevenbridges.commodifiedOn": 1565776372,
            "https://sevenbridges.comproject": "uros_sipetic/gatk-4-1-0-0-demo",
            "https://sevenbridges.comprojectName": "GATK 4.1.0.0 - Demo",
            "https://sevenbridges.compublisher": "sbg",
            "https://sevenbridges.comrevision": 7,
            "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/26",
            "https://sevenbridges.comrevisionsInfo": [
                {
                    "https://sevenbridges.commodifiedBy": "uros_sipetic",
                    "https://sevenbridges.commodifiedOn": 1552929960,
                    "https://sevenbridges.comrevision": 0,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/7"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1554493122,
                    "https://sevenbridges.comrevision": 1,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/14"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1554720843,
                    "https://sevenbridges.comrevision": 2,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/15"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1554999276,
                    "https://sevenbridges.comrevision": 3,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/16"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1559740771,
                    "https://sevenbridges.comrevision": 4,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/18"
                },
                {
                    "https://sevenbridges.commodifiedBy": "veliborka_josipovic",
                    "https://sevenbridges.commodifiedOn": 1559746042,
                    "https://sevenbridges.comrevision": 5,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/19"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nemanja.vucic",
                    "https://sevenbridges.commodifiedOn": 1559750444,
                    "https://sevenbridges.comrevision": 6,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/20"
                },
                {
                    "https://sevenbridges.commodifiedBy": "nens",
                    "https://sevenbridges.commodifiedOn": 1565776372,
                    "https://sevenbridges.comrevision": 7,
                    "https://sevenbridges.comrevisionNotes": "Copy of veliborka_josipovic/gatk-4-1-0-0-toolkit-dev/gatk-mergevcfs-4-1-0-0/26"
                }
            ],
            "https://sevenbridges.comsbgMaintained": false,
            "https://sevenbridges.comtoolAuthor": "Broad Institute",
            "https://sevenbridges.comtoolkit": "GATK",
            "https://sevenbridges.comtoolkitVersion": "4.0.12.0",
            "https://sevenbridges.comvalidationErrors": []
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://sevenbridges.com",
        "dct": "http://purl.org/dc/terms/",
        "foaf": "http://xmlns.com/foaf/0.1/"
    }
}
